<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_section_headings extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
			
	protected function content($atts, $content = null) {
		
		// Get and extract shortcode attributes
		$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
		extract( $atts );
		
		$sc_class   = 'qodx_heading ' . $type . '-block';
									
		$el_class   = esc_attr( $this->getExtraClass($el_class) );		
		$css_class  = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);		
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data  = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);
				
		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
				
		$alignment = $alignment != 'left' ? ' text-' . $alignment : '';
		$output = '';
		
		if ( $container ) {
			$output .= '<div class="container">';
				$output .= '<div class="row">';
		}
		
		$output .= '<div class="'.$css_class.'"'.$anim_data.'>';
			$output .= '<div class="' . $type . '-block-container' . $alignment . '">';
				$output .= "\n\t".$content;
				if ( $separator ) {
					$output .= '<div class="line-separator"></div>';
				}
        	$output .= '</div>'; // End - "title-block-container"
        $output .= '</div>'; // End - "title-block"
		
		if ( $container ) {
				$output .= '</div>'; // End - "row"
			$output .= '</div>'; // End - "container"
		}
		
        return $output;
    }
	
}

/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {

	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;
	$add_qodx_extra_class         = $add_qodx_sc_func->getWTExtraClass();
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name'          => esc_html__( 'Section Headings', 'qodux_fw' ),
		'base'          => 'qodx_section_headings',
		'icon'          => 'qodx-icon-section_headings fa fa-header',
		'class'         => 'qodx_vc_sc_section_headings',
		'wrapper_class' => 'clearfix',		
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Add headings for custom sections', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Type', 'qodux_fw' ),
				'param_name'    => 'type',
				'value'         => array( 
					esc_html__( 'Default', 'qodux_fw' ) => 'title', 
					esc_html__( 'Cta', 'qodux_fw' )     => 'cta'
				),
				'description'   => esc_html__( 'Select headings block type.', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Alignment', 'qodux_fw' ),
				'param_name'    => 'alignment',
				'value'         => array( esc_html__( 'Left', 'qodux_fw' ) => 'left', esc_html__( 'Right', 'qodux_fw' ) => 'right', esc_html__( 'Center', 'qodux_fw' ) => 'center'),
				'std'           => 'left',
				'description'   => esc_html__( 'Select content alignment.', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Display separator?', 'qodux_fw' ),
				'param_name'	=> 'separator',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => 'yes' ),
				'description'   => esc_html__( 'Check this option to display a separator line.', 'qodux_fw' ),
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Container for element?', 'qodux_fw' ),
				'param_name'	=> 'container',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => 'yes' ),
				'description'   => esc_html__( 'Check this option to wrap the element with a container block.', 'qodux_fw' ),
			),			
			array(
				'type'          => 'textarea_html',
				'holder'        => 'div',
				'heading'       => esc_html__( 'Section Headings', 'qodux_fw' ),
				'param_name'    => 'content',
				'value'         => '<h2>' . esc_html__( 'H2 text block. Click edit button to change this text', 'qodux_fw' ) . '</h2><p>' . esc_html__( 'Paragraph text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit', 'qodux_fw' ).'</p>'
			),
			
			$add_qodx_extra_class,
			$add_qodx_css_animation,
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay,
			
			array(
				'type'          => 'css_editor',
				'heading'       => esc_html__( 'Css', 'qodux_fw' ),
				'param_name'    => 'css',
				'group'         => esc_html__( 'Design options', 'qodux_fw' )
			)
		)
	));
	
}