<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_timeline extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
				
	protected function content($atts, $content = null) {
		
		// Get and extract shortcode attributes
		$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
		extract( $atts );
		
		$sc_class = 'qodx_timeline_sc';		
		
		$block_title = esc_html( $block_title );
		$icon        = esc_html( $icon );
		$title       = esc_html( $title );
		$img_size    = esc_html( $img_size );
		$date        = esc_html( $date );
				
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = ' id="' . esc_attr( trim($el_id) ) . '"';
		} else {
			$el_id = '';
		}		
						
		$el_class  = esc_attr( $this->getExtraClass($el_class) );
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);	
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);		
							
		$timeline_item_start = $timeline_item_end = $block_title_out = $img_out = $date_out = $title_out = $heading_link_to = $content_out = '';
		
		if ($block_title) {
			$block_title_out .= '<div class="timeline-block-title">';
				$block_title_out .= '<h3><i class="' . $icon . '"></i><span>' . $block_title . '</span></h3>';
			$block_title_out .= '</div>';
		}			
						
		if ($date) {
			$date_out .= '<div class="date-block">';
				$date_out .= '<div class="date-block-container">';
					$date_out .= '<span><i class="fa fa-clock-o"></i>' . $date . '</span>';
				$date_out .= '</div>';
			$date_out .= '</div>';
		}		
		
		// parse heading link
		$heading_link = ($heading_link=='||') ? '' : $heading_link;
		$heading_link = vc_build_link($heading_link);
		$a_heading_href = $heading_link['url'];
		
		$a_heading_title = $heading_link['title'];
		$a_heading_title_output = ($a_heading_title!='') ? ' title="' . esc_attr( $a_heading_title ) .'"' : '';
		
		$a_heading_target = $heading_link['target'];
		$a_heading_target_output = ($a_heading_target!='') ? ' target="' . $a_heading_target .'"' : '';
		
		if (!empty($a_heading_href)) {
			$heading_link_to = esc_url( $a_heading_href );
		}
		
		
		if ($image) {		
			$img_id = preg_replace('/[^\d]/', '', $image);
			$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));	
			$img_output = $img['thumbnail'];			
			
			$img_out .= '<div class="timeline-header relative-image">';
				$img_out .= "\n\t".'<div class="image-block">';
					$img_out .= "\n\t\t".'<div class="image-block-container">';
						if ( !empty($heading_link_to) ) {
							$img_out .= "\n\t\t\t" . '<a href="'.$heading_link_to.'"' . $a_heading_title_output . $a_heading_target_output .'>'.$img_output.'</a>';
						} else {
							$img_out .= "\n\t\t\t" . $img_output;
						}
					$img_out .= "\n\t\t".'</div>';
				$img_out .= "\n\t".'</div>';
			$img_out .= '</div>';
		}
		
		if ($title) {
			$title = !empty($heading_link_to) ? '<a href="'.$heading_link_to.'"' . $a_heading_title_output . $a_heading_target_output .'>' . $title . '</a>' : $title . '</h4>';
			$title_out .= '<h4>' .$title . '</h4>';
		}		
		
		if ($content) {
			$content_out .= $content;
		}		
				
		if ($date || $content || $title) {
			$timeline_item_start .= '<div class="timeline-block-item">';
				$timeline_item_start .= '<div class="timeline-block-item-container">';
					$timeline_item_start .= $img_out; // Image goes here			
					$timeline_item_start .= '<div class="timeline-footer">';				
						// Content goes here				
					$timeline_item_end   .= '</div>'; 
				$timeline_item_end   .= '</div>'; 
			$timeline_item_end   .= '</div>'; 
		} 
		
		$no_padding = $no_padding ? ' no-padding' : '';
					
		$output = '<div'.$el_id.' class="'.$css_class.' timeline-block"'.$anim_data.'>';
		
	        $output .= "\n\t".'<div class="timeline-block-container' . $no_padding . '">';
			
				$output .= $block_title_out;
				$output .= $timeline_item_start;
					$output .= $date_out;
					$output .= $title_out;
					$output .= $content_out;		
				$output .= $timeline_item_end;
				
	        $output .= "\n\t".'</div>';
        $output .= '</div>';
		
        return $output;
								
    }
	
}
	
/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {

	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;
	$add_qodx_extra_id            = $add_qodx_sc_func->getWTExtraId();
	$add_qodx_extra_class         = $add_qodx_sc_func->getWTExtraClass();
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name'          => esc_html__( 'Timeline', 'qodux_fw' ),
		'base'          => 'qodx_timeline',
		'icon'          => 'qodx-icon-timeline fa fa-history',
		'class'         => 'qodx_vc_sc_timeline',
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Build a custom timeline', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Block title', 'qodux_fw' ),
				'param_name'    => 'block_title',
				'description'   => esc_html__( 'Block title for timeline element.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Block title icon', 'qodux_fw' ),
				'param_name'    => 'icon',
				'value'         => 'fa fa-graduation-cap',
				'description'   => '<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank">Font Awesome</a>, <a href="http://entypo.com/" target="_blank">Entypo</a> or <a href="http://glyphicons.com/" target="_blank">Glyphicons</a> accepted. (use "fa fa-", "entypo-" or "glyphicon-" prefix - for example "<strong>fa fa-adjust, entypo-flag or glyphicon-leaf</strong>"'
			),
			array(
				'type'          => 'attach_image',
				'heading'       => esc_html__( 'Image', 'qodux_fw' ),
				'param_name'    => 'image',
				'value'         => '',
				'description'   => esc_html__( 'Select image from media library.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Image size', 'qodux_fw' ),
				'param_name'    => 'img_size',
				'value'         => 'full',
				'description'   => esc_html__( 'Enter image size. Example: "thumbnail", "medium", "large", "full" or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Date / Step', 'qodux_fw' ),
				'param_name'    => 'date',
				'description'   => esc_html__( 'Date / step for timeline element.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Title', 'qodux_fw' ),
				'param_name'    => 'title',
				'description'   => esc_html__( 'Title for timeline element.', 'qodux_fw' )
			),
			array(
				'type'          => 'vc_link',
				'heading'       => esc_html__( 'Title link', 'qodux_fw' ),
				'param_name'    => 'heading_link',
				'description'   => esc_html__( 'Select URL if you want to have a link on title.', 'qodux_fw' )
			),
			array(
				'type'          => 'textarea_html',
				'heading'       => esc_html__( 'Text', 'qodux_fw' ),
				'param_name'    => 'content',
				'value' 		=>  '<p>' . esc_html__( 'I am text block. Click edit button to change this text.', 'qodux_fw' ). '</p>',
				'description'   => esc_html__( 'Add text for timeline.', 'qodux_fw' )
			),
			array(
				'type'          => 'checkbox',
				'heading'       => esc_html__( 'Remove timeline item padding?', 'qodux_fw' ),
				'param_name'    => 'no_padding',
				'description'   => esc_html__( 'If selected, timeline item will have no padding.', 'qodux_fw' ),
				'value'         => Array(esc_html__( 'Yes, please', 'qodux_fw' ) => 'yes')
			),
			
			$add_qodx_extra_id,
			$add_qodx_extra_class,	
			$add_qodx_css_animation,
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay,		
									
			array(
				'type'          => 'css_editor',
				'heading'       => esc_html__( 'Css', 'qodux_fw' ),
				'param_name'    => 'css',
				'group'         => esc_html__( 'Design options', 'qodux_fw' )
			)
		)
	));	
	
}