<?php
class Qodx_Admin {
	function qodx_init(){
		$this->qodx_functions();
		add_action('admin_menu', array(&$this,'focus_wp_menus'));
		add_action('admin_notices',  array(&$this,'qodx_warnings'));
		
		$this->focus_wp_metaboxes();	
		add_action('wp_ajax_theme-flush-rewrite-rules', array(&$this,'flush_rewrite_rules'));
		
		add_action('admin_init', array(&$this,'qodx_after_theme_is_activated'));
	}
	/**
	 * Check if users need to set the file permissions in order to support the theme, and if not, displays warnings messages in admin option page.
	 */
	function qodx_warnings(){
		global $wp_version;

		$warnings = array();
		if(!qodx_check_wp_version()){
			$warnings[]='Wordpress version(<b>'.$wp_version.'</b>) is too low. Please upgrade to the latest version.';
		}
		if(!function_exists("imagecreatetruecolor")){
			$warnings[]='GD Library Error: <b>imagecreatetruecolor does not exist</b>. Please contact your host provider and ask them to install the GD library, otherwise this theme won\'t work properly.';
		}
		if(!is_writeable(get_template_directory() . '/css')){
			$warnings[]='The css folder (<b>'.str_replace( WP_CONTENT_DIR, '', get_template_directory() . '/css' ).'</b>) is not writeable. Please set the correct file permissions (<b>\'777\' or \'755\'</b>), otherwise this theme won\'t work properly.';
		}		
		if(!file_exists(get_template_directory() . '/css'.DIRECTORY_SEPARATOR.'skin.css')){
			$warnings[]='The skin style file (<b>'.str_replace( WP_CONTENT_DIR, '', get_template_directory() . '/css' ).'/skin.css'.'</b>) doesn\'t exists or it was deleted. Please manually create this file or click on \'Save changes\' and it will be automatically created.';
		}
		if(!is_writeable(get_template_directory() . '/css'.DIRECTORY_SEPARATOR.'skin.css')){
			$warnings[]='The skin style file (<b>'.str_replace( WP_CONTENT_DIR, '', get_template_directory() . '/css' ).'/skin.css'.'</b>) is not writeable. Please set the correct permissions (<b>\'777\' or \'755\'</b>), otherwise this theme won\'t work properly.';
		}					
		
		$str = '';
		if(!empty($warnings)){
			$str = '<ul>';
			foreach($warnings as $warning){
				$str .= '<li>'.$warning.'</li>';
			}
			$str .= '</ul>';
			echo "
				<div id='theme-warning' class='error fade'><p><strong>".sprintf(esc_html__( '%1$s Error Messages', 'qodux_fw' ), QODUX_FRAME_NAME)."</strong><br/>".$str."</p></div>
			";
		}
		
	}
	function qodx_functions(){
		require_once(QODX_FW_DIR . '/admin/functions/theme-functions.php');
		require_once(QODX_FW_DIR . '/admin/functions/custom_scripts.php');
		require_once(QODX_FW_DIR . '/admin/functions/option-media-upload.php');
	}
	/**
	 * Create theme options menu
	 */
	function focus_wp_menus(){
		add_menu_page(QODUX_FRAME_NAME, QODUX_FRAME_NAME, 'edit_theme_options', 'general', array(&$this,'_load_option_page'),'', '59.7');
		add_submenu_page('general', 'General', 'General', 'edit_theme_options', 'general', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Headers', 'Headers', 'edit_theme_options', 'header', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Blog', 'Blog', 'edit_theme_options', 'blog', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Portfolio', 'Portfolio', 'edit_theme_options', 'portfolio', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Fonts', 'Fonts', 'edit_theme_options', 'fonts', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Background', 'Background', 'edit_theme_options', 'background', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Color', 'Color', 'edit_theme_options', 'color', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Sidebar', 'Sidebar', 'edit_theme_options', 'sidebar', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'Footer', 'Footer', 'edit_theme_options', 'footer', array(&$this,'_load_option_page'));
		add_submenu_page('general', 'External API\'s', 'External API\'s', 'edit_theme_options', 'api', array(&$this,'_load_option_page'));
	}
	
	/**
	 * call and display the requested options page
 	 */
	function _load_option_page(){
		include_once (QODX_FW_DIR . '/includes/options.php');
		$page = include(QODX_FW_DIR . '/admin/options' . "/" . $_GET['page'] . '.php');
	
		if($page['auto']){
			new qodx_options($page['name'],$page['options']);
		}
	}
	
	/**
	 * Create post type metabox.
	 */
	function focus_wp_metaboxes(){
		require_once (QODX_FW_DIR . '/includes/metaboxes.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/portfolio.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/team.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/page_general.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/page_bg.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/single.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/featured_video.php');
		require_once (QODX_FW_DIR . '/admin/metaboxes/product_options.php');
	}
	
	function flush_rewrite_rules(){
		flush_rewrite_rules();
		die (1);
	}
	
	function qodx_after_theme_is_activated(){
		if ('themes.php' == basename($_SERVER['PHP_SELF']) && isset($_GET['activated']) && $_GET['activated']=='true' ) {
			qodx_generate_skin_css();
			wp_redirect( admin_url('admin.php?page=general') );
		}
	}
}