<?php

require_once get_template_directory() . '/framework/functions/theme-functions.php';
$qodx = new Qodux_FrameFiles();
$qodx->qodux_init(array());
/**
 * Used for the theme's initialization.
 */
class Qodux_FrameFiles {

	function qodux_init($options) {
		
		/* Define theme's constants. */
		$this->qodux_constants($options);
		
		/* Load theme's functions. */
		$this->qodux_functions();
		
		/* Load Qodux shortcodes within Visual Composer Plugin. */
		$this->qodux_visual_composer_extensions();
		
		/* Initialize the theme's widgets. */
		add_action('widgets_init',array(&$this, 'qodx_widgets'));
		
		/* Load admin files. */
        $this->qodx_admin();
		
	}
	
	/**
	 * Defines the constant paths for use within the theme.
	 */
	function qodux_constants($options) {
		define('QODUX_FRAME_NAME', 'Qodux');
		define('QODUX_FRAME_SLUG','qodux');
	}
	/**
	 * Loads the core theme functions.
	 */
	function qodux_functions() {
		
		/* Load theme's options. */
		$this->qodux_options();
	}
	/**
	 * Loads the theme options.
	 */
	function qodux_options() {
		global $focus_wp_opts;
		$focus_wp_opts = array();
		$option_files = array(
			'general',
			'header',
			'blog',
			'portfolio',
			'background',
			'color',
			'fonts',
			'sidebar',
			'footer',
			'api',
		);
		foreach($option_files as $file){
			$page = include (QODX_FW_DIR . '/admin/options' . "/" . $file.'.php');
			$focus_wp_opts[$page['name']] = array();
			foreach($page['options'] as $option) {
				if (isset($option['default']) && isset($option['id'])) {
					$focus_wp_opts[$page['name']][$option['id']] = $option['default'];
				}
			}
			$focus_wp_opts[$page['name']] = array_merge((array) $focus_wp_opts[$page['name']], (array) get_option('qodux' . '_' . $page['name']));
		}
	}
			
	/**
	 * Extend Visual Composer with Qodux Shortcodes
	 */
	function qodux_visual_composer_extensions() {
		
		if (class_exists('WPBakeryVisualComposerAbstract')) {
					
			require_once (QODX_FW_DIR . '/shortcodes/qodx-visual-composer-extensions.php');
				
		}
		
	}
	
	function qodx_widgets() {
		/* Load each widget file. */
		require_once (QODX_FW_DIR . '/widgets/flickr.php');
		require_once (QODX_FW_DIR . '/widgets/social-font-awesome.php');
		require_once (QODX_FW_DIR . '/widgets/instagram.php');
		require_once (QODX_FW_DIR . '/widgets/facebook.php');
		require_once (QODX_FW_DIR . '/widgets/customlinks.php');
		require_once (QODX_FW_DIR . '/widgets/advertisement-125.php');
		
		/* Register each widget. */
		register_widget('Focus_WP_Widget_Flickr');
		register_widget('Focus_WP_Widget_Social_Font_Awesome');
		register_widget('Focus_WP_Widget_Instagram');
		register_widget('Focus_WP_Widget_Facebook');
		register_widget('Focus_WP_Widget_Custom_Links');
		register_widget('Focus_WP_Widget_Advertisement_125');
	}
	
	/**
	 * Load admin files.
	 */
	function qodx_admin() {
		if (is_admin()) {
			require_once (QODX_FW_DIR . '/admin/admin-panel.php');
			$admin = new Qodx_Admin();
			$admin->qodx_init();
		}
	}
}

?>