<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Qodux Framework - functions
 *
 * @since     1.0.0
 */


/**
 * Enqueue scripts and styles
 *
 * @since     1.0.0
 */
if ( ! function_exists('qodx_fw_enqueue_scripts') ) {	
	function qodx_fw_enqueue_scripts() {
		wp_enqueue_script( 'qodx-visual-composer-extensions-front', QODX_FW_URL. 'shortcodes/assets/qodx-visual-composer-extensions-front.js', array('focus_wp-main', 'focus_wp-plugins'), null, true);
		wp_enqueue_style( 'qodx-visual-composer-extensions-front', QODX_FW_URL. 'shortcodes/assets/qodx-visual-composer-extensions-front.css', array('js_composer_front'), null, 'all');
		$qodx_plugin_data = 'var qodx_plugin_uri = "' . QODX_FW_URL . '";';
   		return  wp_scripts()->add_inline_script( 'qodx-visual-composer-extensions-front', $qodx_plugin_data, $position = 'before' );
	}		
	add_action( 'wp_enqueue_scripts', 'qodx_fw_enqueue_scripts', 10 );	
}

// Allow Shortcodes in Sidebar Widgets
add_filter('widget_text', 'do_shortcode');

/**
 * Simple tag shortcode
 *
 * @since     1.0.0
 */
if ( ! function_exists('qodx_shortcode_tag') ) {
	function qodx_shortcode_tag($atts, $content = null, $code) {
		extract(shortcode_atts(array(
			'id'    => '',
			'class' => '',
			'style' => '',
		), $atts));
		
		if (!empty($id)) $id = ' id="'.$id.'"';
		if (!empty($class)) $class = ' class="'.$class.'"';
		if (!empty($style)) $style = ' style="'.$style.'"';
			
		$content = do_shortcode(stripslashes($content));	
		return <<<HTML
		<{$code}{$id}{$class}{$style}>{$content}</{$code}>
HTML;
	}
	add_shortcode('div',  'qodx_shortcode_tag');
	add_shortcode('span', 'qodx_shortcode_tag');
	add_shortcode('i',    'qodx_shortcode_tag');
}

/**
 * Echo escaped post title
 *
 * @since     1.0.0
 */
if ( ! function_exists('qodx_esc_title') ) {
	function qodx_esc_title() {
		//echo focus_wp_get_esc_title();
	}
}

/**
 * Return escaped post title
 *
 * @since     1.0.0
 */
if ( ! function_exists('qodx_esc_title') ) {
	function focus_wp_get_esc_title() {
		return esc_attr( the_title_attribute( 'echo=0' ) );
	}
}

/**
 * @param FW_Ext_Backups_Demo[] $demos
 * @return FW_Ext_Backups_Demo[]
 *
 * @since     1.0.0
 */
if ( ! function_exists('_filter_theme_fw_ext_backups_demos') ) {
	function _filter_theme_fw_ext_backups_demos($demos) {
		$demos_array = array(
			'focusv1' => array(
				'title' => __('First Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv1.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp',
			),
			'focusv2' => array(
				'title' => __('Second Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv2.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp/v1/',
			),
			'focusv3' => array(
				'title' => __('Third Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv3.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp/v2/',
			),
			'focusv4' => array(
				'title' => __('Fourth Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv4.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp/v3/',
			),
			'focusv5' => array(
				'title' => __('Fifth Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv5.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp/v4/',
			),
			'focusv6' => array(
				'title' => __('Sixth Version', 'qodux_fw' ),
				'screenshot' => 'http://xml.epic-webdesign.com/unyson/focus-wp/focusv6.jpg',
				'preview_link' => 'http://demo.epic-webdesign.com/focus-wp/v5/',
			),
			// ...
		);
	
		$download_url = 'http://xml.epic-webdesign.com/unyson/focus-wp/';
	
		foreach ($demos_array as $id => $data) {
			$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
				'url' => $download_url,
				'file_id' => $id,
			));
			$demo->set_title($data['title']);
			$demo->set_screenshot($data['screenshot']);
			$demo->set_preview_link($data['preview_link']);
	
			$demos[ $demo->get_id() ] = $demo;
	
			unset($demo);
		}
	
		return $demos;
	}
	add_filter('fw:ext:backups-demo:demos', '_filter_theme_fw_ext_backups_demos');
}