<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_gmap extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
			
	protected function content($atts, $content = null) {
		
		// Get and extract shortcode attributes
		$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
		extract( $atts );			
		
		wp_enqueue_script('qodx-extend-gmap-api');		
		
		if ($clusters==true) {
			wp_enqueue_script('qodx-extend-gmap-markerclusterer');
		}
		
		wp_enqueue_script('qodx-extend-gmap');
		
		$sc_class = 'qodx_gmap_sc';
		
		$address  = QODX_VCSC_ValidateMarkerText($address);
		$height   = (int)$height;
		$zoom     = (int)$zoom;
		$fit_bounds            = $fit_bounds            ? 1 : 0;
		$center_on_markerclick = $center_on_markerclick ? 1 : 0;
		$clusters              = $clusters              ? 1 : 0;
		$scrollwheel           = $scrollwheel           ? 'true' : 'false';
		
		if ($theme != '') {
			$theme = rawurldecode(base64_decode(strip_tags($theme)));
		} else {
			$theme = '[]';
		}	
		
		if ($marker_data != '') {
			wp_enqueue_script('qodx-extend-gmap-infobox');
			$marker_data = rawurldecode(base64_decode(strip_tags($marker_data)));
        	$markers     = json_decode( str_replace('``', '"', $marker_data), true);
		} else {
        	$markers = null;
		}		
				
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = ' id="' . esc_attr( trim($el_id) ) . '"';
		} else {
			$el_id = $sc_class . '-' . $id;
		}		
		
		$markers_out = '';
		
		if(!empty($markers)):		
			$countMarkers = count($markers);
			$i = 0;
						
			foreach ($markers as $marker):
			
				$marker_address  = QODX_VCSC_ValidateMarkerText($marker['m_address']);
				// since 1.3 version, marker lat/lng is saved on marker address input which means we can use it directly
				$marker_lat_lng   = (isset($marker['m_lat_lng']))  ? $marker['m_lat_lng'] : '';
								
				$marker_icon_url  = (isset($marker['m_icon_url']) && !empty($marker['m_icon_url'])) ? $marker['m_icon_url'] : QODX_FW_DIR . '/shortcodes/assets/lib/img/marker.png';
				$marker_image_url = (isset($marker['m_image_url']) && !empty($marker['m_image_url'])) ? $marker['m_image_url'] : '';
				
				$marker_link     = QODX_VCSC_ValidateMarkerText($marker['m_link']);
				$marker_title    = QODX_VCSC_ValidateMarkerText($marker['m_title']);
				$marker_desc     = QODX_VCSC_ValidateMarkerText($marker['m_desc']);
				$marker_img_text = QODX_VCSC_ValidateMarkerText($marker['m_img_text']);
												
				$m_address_out    = '"address": "'     . $marker_address   . '", ';
				$m_lat_lng_out    = '"lat_lng": "'     . $marker_lat_lng   . '", ';
				$m_link_out       = '"URL": "'         . $marker_link      . '", ';
				$m_title_out      = '"title": "'       . $marker_title     . '", ';
				$m_desc_out       = '"description": "' . $marker_desc      . '", ';
				$m_image_out      = '"image": "'       . $marker_image_url . '", ';
				$m_icon_out       = '"icon": "'        . $marker_icon_url  . '", ';
				$m_image_text_out = '"image_text": "'  . $marker_img_text  . '"';
				
				if(++$i === $countMarkers) {
					// last marker
					$markers_out .= '{' . $m_address_out . $m_lat_lng_out . $m_link_out . $m_title_out . $m_desc_out . $m_image_out . $m_icon_out . $m_image_text_out . '}';
				} else {
					$markers_out .= '{' . $m_address_out . $m_lat_lng_out . $m_link_out . $m_title_out . $m_desc_out . $m_image_out . $m_icon_out . $m_image_text_out . '},';
				}
			
			endforeach; 
		endif;
						
		$el_class  = esc_attr( $this->getExtraClass($el_class) );		
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class, $this->settings['base']);
		
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);
		
		$output = '';		
			
		$output .= '<div id="'.$el_id.'" class="'.$css_class.'"'.$anim_data.' style="min-height: '.$height.'px">';		
		if(empty($address)) {
			$output .= '<p>Please fill the address field within Visual Composer interface to get a working google map.</p>';
		}		
		$output .= '</div>';
		
		if(!empty($address)) {
		$output .= " 
<script type=\"text/javascript\">
	jQuery(document).ready(function($) {
		var map_options = {
			map_id  : '$el_id',
			address : '$address',
			zoom    : $zoom,
			theme   : $theme,
			markers : [
				$markers_out
			],
			fit_to_markers        : $fit_bounds,
			center_on_markerclick : $center_on_markerclick,
			clusters              : $clusters,
			scrollwheel           : $scrollwheel
		};
		//console.log(map_options);
		qodx_vcsc_extend_google_map(map_options);	
	});
</script>";
}
		
        return $output;
    }
	
}

/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {
		
	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;
	$add_qodx_extra_id            = $add_qodx_sc_func->getWTExtraId();
	$add_qodx_extra_class         = $add_qodx_sc_func->getWTExtraClass();
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name'          => esc_html__( 'Google Map', 'qodux_fw' ),
		'base'          => 'qodx_gmap',
		'icon'          => 'qodx-icon-gmap fa fa-map-marker',
		'class'         => 'qodx_vc_sc_gmap',
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Google map with custom markers', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Map address', 'qodux_fw' ),
				'holder'        => 'div',
				'param_name'    => 'address',
				'description'   => esc_html__( 'Address where the map should point (ex. "London, UK").', 'qodux_fw' )
			),
			array(
				'type'          => 'qodx_gmap_markers',
				'heading'       => 'Map markers',
				'holder'        => 'div',
				'param_name'    => 'map_markers',
				'value'         => ''
			),
			array(
				'type'          => 'qodx_range',
				'heading'       => esc_html__( 'Map height', 'qodux_fw' ),
				'param_name'    => 'height',
				'value'         => '100',
				'min'           => '100',
				'max'           => '1000',
				'step'          => '1',
				'unit'          => 'px',
				'description'   => esc_html__( 'Minim height of the map in px.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			
			array(
				'type'          => 'qodx_range',
				'heading'       => esc_html__( 'Map zoom', 'qodux_fw' ),
				'param_name'    => 'zoom',
				'value'         => '14',
				'min'           => '0',
				'max'           => '19',
				'step'          => '1',
				//'unit'          => 'px',
				'description'   => esc_html__( 'Map zoom level from 0 to 19.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Fit markers?', 'qodux_fw' ),
				'param_name'	=> 'fit_bounds',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => true),
				'description'   => esc_html__( 'Set map zoom to cover all visible markers.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Center & zoom on marker click?', 'qodux_fw' ),
				'param_name'	=> 'center_on_markerclick',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => true),
				'description'   => esc_html__( 'Auto center & zoom the map on marker click event.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Group / cluster markers?', 'qodux_fw' ),
				'param_name'	=> 'clusters',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => true),
				'description'   => esc_html__( 'Group markers that are relatively close together into marker areas.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Scroll wheel?', 'qodux_fw' ),
				'param_name'	=> 'scrollwheel',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => true),
				'description'   => esc_html__( 'If false, disables scrollwheel zooming in Street View.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'type'          => 'textarea_raw_html',
				'heading'       => esc_html__( 'Map theme', 'qodux_fw' ),
				//'holder'        => 'div',
				'param_name'    => 'theme',
				'value'         => '',
				'description'   => esc_html__( 'JavaScript Style Array. Set your own style or see ', 'qodux_fw' ) . '<a href="http://snazzymaps.com/" target="_blank">http://snazzymaps.com</a>' . esc_html__( ' for more free themes. Also you can use ', 'qodux_fw' ) . '<a href="http://gmaps-samples-v3.googlecode.com/svn/trunk/styledmaps/wizard/index.html" target="_blank">this online editor</a>' . esc_html__( ' to create a personalized google map. Copy / paste here the JSON array.', 'qodux_fw' ),
				'group'         => esc_html__( 'Advanced map settings', 'qodux_fw' )
			),
			array(
				'heading'       => '',
				'type'          => 'textarea_raw_html',
				//'holder'        => 'div',
				'param_name'    => 'marker_data',
				'value'         => '',
			),				
			array(
				'type'                => 'qodx_loadfile',
				'heading'             => '',
				'param_name'          => 'el_file',
				'value'               => '',
				'file_type'           => 'js',
				'file_path'           => 'qodx-visual-composer-extend-element.min.js',
				'param_holder_class'  => 'qodx_loadfile_field',
				'description'         => ''
			),
			
			$add_qodx_extra_id,
			$add_qodx_extra_class,
			$add_qodx_css_animation,
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay
						
		)
	));
	
}