<?php
/**
 * Visual Composer Row Configuration
 *
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Global var for class
global $qodx_vc_row_config;

// Start Class
if ( ! class_exists( 'QODX_VC_Row_Config' ) ) {
	
	class QODX_VC_Row_Config {

		/**
		 * Main constructor
		 *
		 */
		public function __construct() {

			// Add new parameters to the row
			add_action( 'init', array( $this, 'add_remove_params' ) );

		}

		/**
		 * Adds new params for the VC Rows
		 *
		 */
		public function add_remove_params() {

			// Array of params to add
			$add_params = array();
			
			$add_params['separator'] = array(
				'type'              			=> 'qodx_separator',
				'heading'           			=> '',
				'param_name'        			=> 'separator',
				'separator'             		=> 'Row Extended Settings',
				'description'       			=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['min_height'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Minimum Height', 'focus_wp' ),
				'param_name'            		=> 'min_height',
				'value'                 		=> '0',
				'min'                   		=> '0',
				'max'                   		=> '2048',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> esc_html__( 'Define the minimum height for this row.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['center_row'] = array(
				'type'							=> 'checkbox',
				'class'							=> '',
				'heading'						=> esc_html__( 'Center Row Content?', 'focus_wp' ),
				'param_name'					=> 'center_row',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				/*'std'                           => 'yes',*/
				'description'					=> sprintf( esc_html__( 'Use this option to horizontally center the inner content of this row. %s .', 'focus_wp' ), '<strong>Useful when using pages based on \'Full Screen\' templates.</strong>' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['full_mobile_row'] = array(
				'type'							=> 'checkbox',
				'class'							=> '',
				'heading'						=> esc_html__( 'Full Screen Width on Mobiles?', 'focus_wp' ),
				'param_name'					=> 'full_mobile_row',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'					=> sprintf( esc_html__( 'Use this option to keep full width content of this row on mobiles. %s .', 'focus_wp' ), '<strong>Useful when using pages based on \'Full Screen\' templates.</strong>' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['default_bg'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'Default Background?', 'focus_wp' ),
				'param_name'					=> 'default_bg',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add a default background color.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);	
			$add_params['default_skin_bg'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'Default Skin Background?', 'focus_wp' ),
				'param_name'					=> 'default_skin_bg',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add a default skin background color.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['default_border'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'Default Border?', 'focus_wp' ),
				'param_name'					=> 'default_border',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add a default border.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['shadow'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'Drop Shadow?', 'focus_wp' ),
				'param_name'					=> 'shadow',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add a default shadow to this row.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['typography'] = array(
				'type' 							=> 'dropdown',
				'heading' 						=> esc_html__( 'Typography Style', 'focus_wp' ),
				'param_name' 					=> 'typography',
				'value' 						=> array(
					esc_html__( 'Dark Text', 'focus_wp' )	=> 'dark',
					esc_html__( 'White Text', 'focus_wp' )	=> 'light'
				),
				'description' 					=> esc_html__( 'Select typography style.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bck_color'] = array(
				'type'                          => 'colorpicker',
				'heading'                       => esc_html__( 'Background Color', 'focus_wp' ),
				'param_name'                    => 'bck_color',
				'description'                   => esc_html__( 'Select background color for this row.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bg_type'] = array(
				'type' 							=> 'dropdown',
				'heading' 						=> esc_html__( 'Background Type', 'focus_wp' ),
				'param_name' 					=> 'bg_type',
				'value' 						=> array(
					esc_html__( 'None', 'focus_wp' )			  => '',
					esc_html__( 'Simple Image', 'focus_wp' )	  => 'image',
					esc_html__( 'Fixed Image', 'focus_wp' )	  => 'fixed',
					esc_html__( 'Parallax Image', 'focus_wp' ) => 'parallax',
					esc_html__( 'YouTube Video', 'focus_wp' )  => 'youtube',
					esc_html__( 'HTML5 Video', 'focus_wp' )	  => 'html_video',
				),
				'admin_label' 					=> true,
				'description' 					=> esc_html__( 'Select background type for this row.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bck_image'] = array(
				'type'							=> 'attach_image',
				'heading'						=> esc_html__( 'Background Image', 'focus_wp' ),
				'param_name'					=> 'bck_image',
				'value'							=> '',
				'description'					=> esc_html__( 'Select the background image for your row.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> array('image', 'fixed', 'parallax')
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bg_size'] = array(
				'type'                  		=> 'dropdown',
				'heading'               		=> esc_html__( 'Background Image Size', 'focus_wp' ),
				'param_name'            		=> 'bg_size',
				'value'                 		=> array(
					esc_html__( 'Full Size Image', 'focus_wp' )		=> 'full',
					esc_html__( 'Large Size Image', 'focus_wp' )		=> 'large',
					esc_html__( 'Medium Size Image', 'focus_wp' )	=> 'medium',
					esc_html__( 'Thumbnail Size Image', 'focus_wp' )	=> 'thumbnail',
				),
				'description'           		=> esc_html__( 'Select which image size based on WordPress settings should be used.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> array('image', 'fixed', 'parallax')
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bg_position'] = array(
				'type' 							=> 'dropdown',
				'heading' 						=> esc_html__( 'Background Position', 'focus_wp' ),
				'param_name' 					=> 'bg_position',
				'value' 						=> array(
					esc_html__( 'Top', 'focus_wp' )	  => 'top',
					esc_html__( 'Middle', 'focus_wp' ) => 'center',
					esc_html__( 'Bottom', 'focus_wp' ) => 'bottom'
				),
				'description' 					=> '',
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> array('image', 'fixed', 'parallax')
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bg_size_standard'] = array(
				'type' 							=> 'dropdown',
				'heading' 						=> esc_html__( 'Background Size', 'focus_wp' ),
				'param_name' 					=> 'bg_size_standard',
				'value' 						=> array(
					esc_html__( 'Cover', 'focus_wp' ) 	=> 'cover',
					esc_html__( 'Contain', 'focus_wp' ) 	=> 'contain',
					esc_html__( 'Initial', 'focus_wp' ) 	=> 'initial',
					esc_html__( 'Auto', 'focus_wp' ) 	=> 'auto',
				),
				'description' 					=> '',
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> array('image', 'fixed', 'parallax')
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['bg_repeat'] = array(
				'type' 							=> 'dropdown',
				'heading' 						=> esc_html__( 'Background Repeat', 'focus_wp' ),
				'param_name' 					=> 'bg_repeat',
				'value' 						=> array(
					esc_html__( 'No Repeat', 'focus_wp' )	=> 'no-repeat',
					esc_html__( 'Repeat X + Y', 'focus_wp' )	=> 'repeat',
					esc_html__( 'Repeat X', 'focus_wp' )		=> 'repeat-x',
					esc_html__( 'Repeat Y', 'focus_wp' )		=> 'repeat-y'
				),
				'description' 					=> '',
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> array('image', 'fixed', 'parallax')
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			
			// YouTube Video Background
			$add_params['youtube_video_id'] = array(
				'type'              			=> 'textfield',
				'heading'           			=> esc_html__( 'YouTube Video ID', 'focus_wp' ),
				'param_name'        			=> 'youtube_video_id',
				'value'             			=> '',
				'description'       			=> esc_html__( 'Enter the YouTube video ID.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'youtube'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['yt_video_controls'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'YouTube Video Controls?', 'focus_wp' ),
				'param_name'					=> 'yt_video_controls',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add controls for youtube video.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'youtube'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['yt_video_bg_img'] = array(
				'type'							=> 'attach_image',
				'heading'						=> esc_html__( 'YouTube Background Image', 'focus_wp' ),
				'param_name'					=> 'yt_video_bg_img',
				'value'							=> '',
				'description'					=> esc_html__( 'Select the youtube background image for your row. This is a placeholder for mobiles where the video doesn\'t work.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'youtube'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			
			// HTML5 Video Background
			$add_params['html_mp4'] = array(
				'type'              			=> 'textfield',
				'heading'           			=> esc_html__( 'HTML5 Mp4 Video Link', 'focus_wp' ),
				'param_name'        			=> 'html_mp4',
				'value'             			=> '',
				'description'       			=> esc_html__( 'Enter HTML5 \'mp4\' path.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'html_video'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['html_wbm'] = array(
				'type'              			=> 'textfield',
				'heading'           			=> esc_html__( 'HTML5 Webm Video Link', 'focus_wp' ),
				'param_name'        			=> 'html_wbm',
				'value'             			=> '',
				'description'       			=> esc_html__( 'Enter HTML5 \'wbm\' path.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'html_video'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);		
			$add_params['html_ogv'] = array(
				'type'              			=> 'textfield',
				'heading'           			=> esc_html__( 'HTML5 Ogv Video Link', 'focus_wp' ),
				'param_name'        			=> 'html_ogv',
				'value'             			=> '',
				'description'       			=> esc_html__( 'Enter HTML5 \'ogv\' path.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'html_video'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);		
			$add_params['html5_video_controls'] = array(
				'type'							=> 'checkbox',
				'heading'						=> esc_html__( 'HTML5 Video Controls?', 'focus_wp' ),
				'param_name'					=> 'html5_video_controls',
				'value'							=> Array( esc_html__( 'Yes please.', 'focus_wp' ) => 'yes' ),
				'description'           		=> esc_html__( 'Check this option to add controls for HTML5 video.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'html_video'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['html_video_bg_img'] = array(
				'type'							=> 'attach_image',
				'heading'						=> esc_html__( 'HTML5 Background Image', 'focus_wp' ),
				'param_name'					=> 'html_video_bg_img',
				'value'							=> '',
				'description'					=> esc_html__( 'Select the youtube background image for your row. This is a placeholder for mobiles where the video doesn\'t work.', 'focus_wp' ),
				'dependency' 					=> array(
					'element' 	=> 'bg_type',
					'value' 	=> 'html_video'
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['bg_color_overlay'] = array(
				'type'                          => 'colorpicker',
				'heading'                       => esc_html__( 'Background Overlay Color', 'focus_wp' ),
				'param_name'                    => 'bg_color_overlay',
				'description'                   => esc_html__( 'Select overlay color for this element.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);	
			$add_params['bg_pattern_overlay'] = array(
				'type'                  		=> 'dropdown',
				'heading'               		=> esc_html__( 'Background Overlay Pattern', 'focus_wp' ),
				'param_name'            		=> 'bg_pattern_overlay',
				'value'                 		=> array(
					esc_html__( 'None', 'focus_wp' )		=> '',
					esc_html__( 'Dotted', 'focus_wp' )	=> 'dotted',
					esc_html__( 'Dashed', 'focus_wp' )	=> 'dashed',
				),
				'description'           		=> esc_html__( 'Select overlay pattern type for this element.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['border_color'] = array(
				'type'							=> 'colorpicker',
				'class'							=> '',
				'heading'						=> esc_html__( 'Border Color', 'focus_wp' ),
				'param_name'					=> 'border_color',
				'value' 						=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['border_style'] = array(
				'type'							=> 'dropdown',
				'class'							=> '',
				'heading'						=> esc_html__( 'Border Style', 'focus_wp' ),
				'param_name'					=> 'border_style',
				'value'							=> array(
					esc_html__( 'Solid', 'focus_wp' )	=> 'solid',
					esc_html__( 'Dotted', 'focus_wp' )	=> 'dotted',
					esc_html__( 'Dashed', 'focus_wp' )	=> 'dashed',
				),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['border_width'] = array(
				'type'							=> 'textfield',
				'class'							=> '',
				'heading'						=> esc_html__( 'Border Width', 'focus_wp' ),
				'param_name'					=> 'border_width',
				'value'							=> '0px 0px 0px 0px',
				'description'					=> sprintf( esc_html__( 'Your border width in pixels. Example: %s (top, right, bottom, left).', 'focus_wp' ), '<strong>1px 1px 1px 1px</strong>' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);	
			
			// Paddings & Margins
			$add_params['separator_2'] = array(
				'type'              			=> 'qodx_separator',
				'heading'           			=> '',
				'param_name'        			=> 'separator_2',
				'separator'             		=> 'Paddings and Margins',
				'description'       			=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['padding_top'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Padding: Top', 'focus_wp' ),
				'param_name'            		=> 'padding_top',
				'value'                 		=> '0',
				'min'                   		=> '0',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);			
			$add_params['padding_bottom'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Padding: Bottom', 'focus_wp' ),
				'param_name'            		=> 'padding_bottom',
				'value'                 		=> '0',
				'min'                   		=> '0',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['padding_left'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Padding: Left', 'focus_wp' ),
				'param_name'            		=> 'padding_left',
				'value'                 		=> '0',
				'min'                   		=> '0',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['padding_right'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Padding: Right', 'focus_wp' ),
				'param_name'            		=> 'padding_right',
				'value'                 		=> '0',
				'min'                   		=> '0',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['margin_top'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Margin: Top', 'focus_wp' ),
				'param_name'            		=> 'margin_top',
				'value'                 		=> '0',
				'min'                   		=> '-250',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['margin_bottom'] = array(
				'type'                  		=> 'qodx_range',
				'heading'               		=> esc_html__( 'Margin: Bottom', 'focus_wp' ),
				'param_name'            		=> 'margin_bottom',
				'value'                 		=> '0',
				'min'                   		=> '-250',
				'max'                   		=> '250',
				'step'                  		=> '1',
				'unit'                  		=> 'px',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			
			// Animations	
			$add_params['separator_3'] = array(
				'type'              			=> 'qodx_separator',
				'heading'           			=> '',
				'param_name'        			=> 'separator_3',
				'separator'             		=> 'Animations',
				'description'       			=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);	
			$add_params['css_animation'] = array(
				'type'                          => 'dropdown',
				'heading'                       => esc_html__( 'CSS WT Animation', 'focus_wp' ),
				'param_name'                    => 'css_animation',
				'value' => array( esc_html__( 'No', 'focus_wp' ) => '', esc_html__( 'Hinge', 'focus_wp' ) => 'hinge', esc_html__( 'Flash', 'focus_wp' ) => 'flash', esc_html__( 'Shake', 'focus_wp' ) => 'shake', esc_html__( 'Bounce', 'focus_wp' ) => 'bounce', esc_html__( 'Tada', 'focus_wp' ) => 'tada', esc_html__( 'Swing', 'focus_wp' ) => 'swing', esc_html__( 'Wobble', 'focus_wp' ) => 'wobble', esc_html__( 'Pulse', 'focus_wp' ) => 'pulse', esc_html__( 'Flip', 'focus_wp' ) => 'flip', esc_html__( 'FlipInX', 'focus_wp' ) => 'flipInX', esc_html__( 'FlipOutX', 'focus_wp' ) => 'flipOutX', esc_html__( 'FlipInY', 'focus_wp' ) => 'flipInY', esc_html__( 'FlipOutY', 'focus_wp' ) => 'flipOutY', esc_html__( 'FadeIn', 'focus_wp' ) => 'fadeIn', esc_html__( 'FadeInUp', 'focus_wp' ) => 'fadeInUp', esc_html__( 'FadeInDown', 'focus_wp' ) => 'fadeInDown', esc_html__( 'FadeInLeft', 'focus_wp' ) => 'fadeInLeft', esc_html__( 'FadeInRight', 'focus_wp' ) => 'fadeInRight', esc_html__( 'FadeInUpBig', 'focus_wp' ) => 'fadeInUpBig', esc_html__( 'FadeInDownBig', 'focus_wp' ) => 'fadeInDownBig', esc_html__( 'FadeInLeftBig', 'focus_wp' ) => 'fadeInLeftBig', esc_html__( 'FadeInRightBig', 'focus_wp' ) => 'fadeInRightBig', esc_html__( 'FadeOut', 'focus_wp' ) => 'fadeOut', esc_html__( 'FadeOutUp', 'focus_wp' ) => 'fadeOutUp', esc_html__( 'FadeOutDown', 'focus_wp' ) => 'fadeOutDown', esc_html__( 'FadeOutLeft', 'focus_wp' ) => 'fadeOutLeft', esc_html__( 'FadeOutRight', 'focus_wp' ) => 'fadeOutRight', esc_html__( 'fadeOutUpBig', 'focus_wp' ) => 'fadeOutUpBig', esc_html__( 'FadeOutDownBig', 'focus_wp' ) => 'fadeOutDownBig', esc_html__( 'FadeOutLeftBig', 'focus_wp' ) => 'fadeOutLeftBig', esc_html__( 'FadeOutRightBig', 'focus_wp' ) => 'fadeOutRightBig', esc_html__( 'BounceIn', 'focus_wp' ) => 'bounceIn', esc_html__( 'BounceInUp', 'focus_wp' ) => 'bounceInUp', esc_html__( 'BounceInDown', 'focus_wp' ) => 'bounceInDown', esc_html__( 'BounceInLeft', 'focus_wp' ) => 'bounceInLeft', esc_html__( 'BounceInRight', 'focus_wp' ) => 'bounceInRight', esc_html__( 'BounceOut', 'focus_wp' ) => 'bounceOut', esc_html__( 'BounceOutUp', 'focus_wp' ) => 'bounceOutUp', esc_html__( 'BounceOutDown', 'focus_wp' ) => 'bounceOutDown', esc_html__( 'BounceOutLeft', 'focus_wp' ) => 'bounceOutLeft', esc_html__( 'BounceOutRight', 'focus_wp' ) => 'bounceOutRight', esc_html__( 'RotateIn', 'focus_wp' ) => 'rotateIn', esc_html__( 'RotateInUpLeft', 'focus_wp' ) => 'rotateInUpLeft', esc_html__( 'RotateInDownLeft', 'focus_wp' ) => 'rotateInDownLeft', esc_html__( 'RotateInUpRight', 'focus_wp' ) => 'rotateInUpRight', esc_html__( 'RotateInDownRight', 'focus_wp' ) => 'rotateInDownRight', esc_html__( 'RotateOut', 'focus_wp' ) => 'rotateOut', esc_html__( 'RotateOutUpLeft', 'focus_wp' ) => 'rotateOutUpLeft', esc_html__( 'RotateOutDownLeft', 'focus_wp' ) => 'rotateOutDownLeft', esc_html__( 'RotateOutUpRight', 'focus_wp' ) => 'rotateOutUpRight', esc_html__( 'RotateOutDownRight', 'focus_wp' ) => 'rotateOutDownRight', esc_html__( 'RollIn', 'focus_wp' ) => 'rollIn', esc_html__( 'RollOut', 'focus_wp' ) => 'rollOut', esc_html__( 'LightSpeedIn', 'focus_wp' ) => 'lightSpeedIn', esc_html__( 'LightSpeedOut', 'focus_wp' ) => 'lightSpeedOut' ),
				'description' => esc_html__( 'Select type of animation if you want this element to be animated when it enters into the browsers viewport. Note: Works only in modern browsers.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['anim_type'] = array(
				'type'                          => 'dropdown',
				'heading'                       => esc_html__( 'WT Animation Visible Type', 'focus_wp' ),
				'param_name'                    => 'anim_type',
				'value'                         => array( esc_html__( 'Animate when element is visible', 'focus_wp' ) => 'qodx_animate_if_visible', esc_html__( 'Animate if element is almost visible', 'focus_wp' ) => 'qodx_animate_if_almost_visible' ),
				'description'                   => esc_html__( 'Select when the type of animation should start for this element.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);
			$add_params['anim_delay'] = array(
				'type'                          => 'textfield',
				'heading'                       => esc_html__( 'WT Animation Delay', 'focus_wp' ),
				'param_name'                    => 'anim_delay',
				'description'                   => esc_html__( 'Here you can set a specific delay for the animation (miliseconds). Example: \'100\', \'500\', \'1000\'.', 'focus_wp' ),
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' )
			);	
				
			$add_params['el_file'] = array(
				'type'                  		=> 'qodx_loadfile',
				'heading'               		=> '',
				'param_name'            		=> 'el_file',
				'value'                 		=> '',
				'file_type'             		=> 'js',
				'file_path'             		=> 'qodx-visual-composer-extend-element.min.js',
				'param_holder_class'            => 'qodx_loadfile_field',
				'description'           		=> '',
				'group' 						=> esc_html__( 'Qodux', 'focus_wp' ),
			);
			
			// Loop through array and add new params
			foreach( $add_params as $key => $val ) {
				vc_add_param( 'vc_row', $val );
				vc_add_param( 'vc_row_inner', $val );
			}
									
		}
		
	}

}
$qodx_vc_row_config = new QODX_VC_Row_Config();