<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register WhoaThemes shortcode.
*/

class WPBakeryShortCode_QODX_blog extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
			
	protected function content($atts, $content = null) {
		
		global $wp_filter;
		$the_content_filter_backup = $wp_filter['the_content'];		
		
		// Get and extract shortcode attributes
		$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
		extract( $atts );	
		
		$sc_class = 'qodx_blog_sc';
				
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = esc_attr( trim($el_id) );
		} else {
			$el_id = $sc_class . '-' . $id;
		}
				
		$el_class = esc_attr( $this->getExtraClass($el_class) );		
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);			
				
		$columns        = (int)$columns;
		$max            = (int)$max;			
		$excerpt_length = (int)$excerpt_length;				
		$read_more_text = esc_html($read_more_text);	
		$auto_slide     = (int)$auto_slide;	
		$slide_items_md = (int)$slide_items_md;	
		$slide_items_sm = (int)$slide_items_sm;	
		$slide_items_xs = (int)$slide_items_xs;
																
		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => $max,
			'order'			 => $order,
			'orderby'		 => $orderby,
		);		
				
		if($category){
			$query['cat'] = $category;
		}
		if($category__and){
			$query['category__and'] = explode(',',$category__and);
		}
		if($category__not_in){
			$query['category__not_in'] = explode(',',$category__not_in);
		}
		if($author){
			$query['author'] = $author;
		}
		if($posts){
			$query['post__in'] = explode(',',$posts);
		}
		
		if ($pagination == 'true') {
			global $wp_version;
			global $paged;
			
			if (is_front_page() && version_compare($wp_version, "3.1", '>=')){//fix wordpress 3.1 paged query
				$paged = (get_query_var('paged')) ? get_query_var('paged') : ((get_query_var('page')) ? get_query_var('page') : 1);
			} else {
				$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
			}
			$query['paged'] = $paged;
		} else {
			$query['showposts'] = $max;
			$paged = NULL;
		}
		
		$qodx_query = new WP_Query($query);
		
		/* Display all post if count = -1 */
		if($max == '-1'){
			$query['posts_per_page'] = $qodx_query->post_count;
		} 
								
		if ($slider == "true") {
			//wp_enqueue_style('wt-extend-swiper-slider');
			wp_enqueue_script('wt-extend-swiper-slider');
		}	
		
		$atts = array(
			'columns'            => $columns,
			'max'                => $max,
			'grid_spaces'        => $grid_spaces,
			'featured_entry'     => $featured_entry,
			'img_width'          => $img_width,
			'img_height'         => $img_height,
			'avatar'             => $avatar,
			'meta'               => $meta,
			'title'              => $title,
			'title_linkable'     => $title_linkable,
			'excerpt'            => $excerpt,
			'excerpt_length'     => $excerpt_length,
			'full'               => $full,
			'read_more'          => $read_more,
			'read_more_text'     => $read_more_text,
			'posts'              => $posts,	
			'category'           => $category,
			'category__and'      => $category__and,
			'category__not_in'   => $category__not_in,
			'author'             => $author,
			'order'              => $order,
			'orderby'            => $orderby,
			
			'pagination'         => $pagination,
			'pagination_align'   => $pagination_align,
			'isotope_grid'       => $isotope_grid,			
			
			'slider'             => $slider,
			'auto_slide'         => $auto_slide,
			'direction'          => $direction,
			'equal_height'       => $equal_height,
			'effect'             => $effect,
			'centered_slides'    => $centered_slides,
			'slide_items_md'     => $slide_items_md,
			'slide_items_sm'     => $slide_items_sm,
			'slide_items_xs'     => $slide_items_xs,
			'grab_cursor'        => $grab_cursor,
			'simulate_touch'     => $simulate_touch,
			'slider_pag'         => $slider_pag,
			'pag_lowest'         => $pag_lowest,
			'slider_nav'         => $slider_nav, 		
		
    		'css_animation'       => $css_animation,
    		'anim_type'           => $anim_type,
    		'anim_delay'          => $anim_delay,
		);
				
		$output = '';
		
		// Automatically disable pagination if slider option is true
		if ($slider == 'true') {
			$pagination = 'false';
		}
		
		$output .= '<div id="'.$el_id.'" class="qodx-blog-wrapper';
		
			/* Blog with slider */
			if ( $slider == 'true' ) {
				$output .= '-slider '.$css_class.'">';
				
				$equal_height = $direction == 'horizontal' && $equal_height == 'true' ? ' swiper-equal-height' : '';
				
				$direction = $direction == 'vertical' ? ' vertical-swiper-slider' : '';
			
				switch($effect){
					case 'fade':
						$effect = ' fade-swiper-slider';
						break;
					case 'coverflow':
						$effect = ' coverflow-swiper-slider';
						break;
					case 'fade':
					default:
						$effect = '';
				}
				
				$centered_slides = $centered_slides == 'true' ? ' center-swiper-slider' : '';			
															
				$output .= '<div id="qodx-swiper-slider-'.$id.'" class="qodx-swiper-slider'.$direction.$equal_height.$effect.$centered_slides.'" data-swiper-items="'.$columns.'" data-swiper-md-items="'.$slide_items_md.'" data-swiper-sm-items="'.$slide_items_sm.'" data-swiper-xs-items="'.$slide_items_xs.'" data-swiper-autoplay="'.$auto_slide.'" data-swiper-grab-cursor="'.$grab_cursor.'" data-swiper-simulate-touch="'.$simulate_touch.'">';
					$output .= '<div class="swiper-wrapper">';		
			
			/* Blog with isotope grid - if pagination and slider are all false */
			} elseif ( $pagination == "false" && $slider == "false" && $isotope_grid ) {
				wp_enqueue_script('wt-extend-isotope');
				$output .= '-isotope filter-items-wrapper qodx_blog_' . $columns . ' '.$css_class.'">';
				
			/* Blog with pagination */	
			} else {
				$output .= ' qodx_blog_' . $columns . ' '.$css_class.'">';
			}
			
				// Blog articles content goes here
				$output .= $this->QODX_VCSC_BlogList($qodx_query,$atts);
			
			if ($slider == 'true') {
					$output .= '</div>'; // End "swiper-wrapper"
					
					// Build Pagination
					if ($slider_pag == "true") {
						$pag_lowest = $pag_lowest ? ' pag-lowest' : '';
						$output .= '<div class="swiper-pagination' . $pag_lowest . '"></div>';
					}
					
					// Build Navigation
					if ($slider_nav == "true") {
						$output .= '<div class="swiper-button-prev">
										<i class="fa fa-angle-left"></i>
									</div>
									<div class="swiper-button-next">
										<i class="fa fa-angle-right"></i>
									</div>';
					}
					
				$output .= '</div>'; // End "qodx-swiper-slider"				
			}
		
		$output .= "</div>"; // End div - "qodx-blog-wrapper"
		
		if ($pagination == 'true') {
			ob_start();
			QODX_VCSC_BlogPageNavi('', '', $qodx_query, $paged, $pagination_align);
			$output .= ob_get_clean();
		}
		
		// Set things back to normal
		wp_reset_postdata();		
		$wp_filter['the_content'] = $the_content_filter_backup;
		return $output;
    }
	
	protected function QODX_VCSC_BlogList(&$qodx_query, $atts) {
		
		extract($atts);		
							
		$layout = 'full';		
		$output = $col_class = $isotope_css = $contentOutput = '';
				
		$grid_spaces = $grid_spaces == "true" ? '' : ' wide-block';
		
		switch($columns){
			case 1:
				$col_class = 'col-md-12 ';
				break;
			case 2:
				$col_class = 'col-md-6 col-sm-6 col-xs-6 ';
				break;
			case 3:
				$col_class = 'col-md-4 col-sm-4 col-xs-12 ';
				break;
			case 6:
				$col_class = 'col-md-2 col-sm-6 col-xs-6 ';
				break;
			case 4:
			case 5:
			default:
				$col_class = 'col-md-3 col-sm-6 col-xs-6 ';
		}
		
		if ( $slider == 'true' ) {
			$col_class = 'col-md-12 ';
		}
				
		if ( $pagination == "false" && $slider == "false" && $isotope_grid ) { 
			$isotope_css = ' isotope-item';
		}	
								
		$i = 0;
		// Get global $post var
		global $post;
		
		if ($qodx_query->have_posts()):
			while ($qodx_query->have_posts()) : 
				$i++;				
											
				$qodx_query->the_post();				
				
				$terms = get_the_terms(get_the_id(), 'category');
				$terms_slug = array();
				if (is_array($terms)) {
					foreach($terms as $term) {
						$terms_slug[] = $term->slug;
					}
				}
				
				$contentOutput = $anim_class = $anim_data = '';
				
				if ( $slider == 'true' ) {
					$output .= '<div class="swiper-slide">';	
						$output .= '<div class="swiper-slide-container">';	
				}
								
				$output .= '<article data-order="'.$i.'" id="post-'.get_the_ID().'" class="' . $col_class . 'qodx-post-item post-block' . $grid_spaces . $isotope_css;
				$output .= ' ' . implode(' ', $terms_slug) . $anim_class . '"';
				$output .= $anim_data . '>';
					$output .= '<div class="post-block-container">';
					
						/* Start - Featured entry */
						if ($featured_entry == 'true') {
							
							$output .= "\n\t" . '<div class="post-media">';
								$thumbnail_type = get_post_meta($post->ID, '_thumbnail_type', true);
										
								switch($thumbnail_type){						
									case "timage" : 
										$output .= focus_wp_generator('focus_wp_blog_featured_image','full',$layout,$img_width,$img_height);
										break;
									case "tvideo" : 
										$video_link = get_post_meta($post->ID,'_featured_video', true);
										$output .= '<div class="blog-thumbnail-video">';
										$output .= focus_wp_video_featured($video_link,'full',$layout,$height='360',$width='480');									
										$output .=  '</div>';							
										break;
									case "tplayer" :
										$player_link = get_post_meta($post->ID,'_thumbnail_player', true);
										$output .= '<div class="blog-thumbnail-player">';
										$output .= focus_wp_media_player('full',$layout,$player_link);
										$output .= '</div>';							
										break;
									case "tslide" : 
										$output .= '<div class="blog-thumbnail-slide">';
										$output .= focus_wp_get_slide('full',$layout,$img_width,$img_height);
										$output .= '</div>';							
										break;
								}
							$output .= "\n\t" . '</div>'; // End div - "post-media"
						}					
						/* End - Featured entry */
						
						if ( $avatar || $meta != '' || ( $title == 'true' && $slider != 'true' ) ){
							
							$output .= "\n\t" . '<div class="post-header">';
							
								/* Start - Gravatar */
								if ( $avatar ){
									$output .= "\n\t\t" . '<div class="blog-post-author">';
										$output .= "\n\t\t" . '<div class="avatar-block">';		
											$output .= '<a href="#">' . get_avatar( get_the_author_meta('user_email', 	get_query_var('author')), '56',$default=esc_url('http://s.gravatar.com/avatar/e18c83a4de25393a9465e613f15b86e0')) . '</a>';
										$output .= "\n\t\t" . '</div>';	 // End div - "avatar-block"		
										$output .= '<span class="theme-color txt-normal">' . get_the_author() . '</span>'; 
									/* Start - Metadata */
									if ( $meta != '' ){									
										$date = false;									
										$metadata = array_map( 'trim', explode( ',', $meta ) );	

										if(is_array($metadata) && !empty($metadata)){

											foreach ( $metadata as $index=>$metaopt ) {												
												switch( $metaopt ) {
													case 'date'       : $date = true;     break;
												}											
											}	

										}
											$output .= QODX_VCSC_BlogMeta($date);
									}
										$output .= "\n\t\t" . '</div>';	 // End div - "blog-post-author"		
									}
								/* End - Gravatar */
								
								/* Start - Post title */
								if ( $title == 'true' && $slider != 'true' ){
									if ( $title_linkable == 'true' ) {								
										$output .= '<h4 class="qodx_post_title"><a href="'.get_permalink().'" rel="bookmark" title="'.sprintf( esc_html__( "Permanent Link to %s", 'qodux_fw' ), get_the_title() ).'">' . get_the_title() . '</a></h4>';
									} else {
										$output .= '<h4 class="qodx_post_title"><span>' . get_the_title() . '</span></h4>';
									}
								}	
								/* End - Post title */															
							
								
							$output .= "\n\t" . '</div>'; // End div - "post-header"
						}
					
						/* Start - Content output */
						if ( ( $title == 'true' && $slider == 'true' ) || $excerpt == 'true' || $read_more == 'true'){				
							$contentOutput .= "\n\t" . '<div class="post-footer">';
						}
				
							// If post title
							if ( $title == 'true' && $slider == 'true' ){
								if ( $title_linkable == 'true' ) {								
									$contentOutput .= '<h4 class="qodx_post_title"><a href="'.get_permalink().'" rel="bookmark" title="'.sprintf( esc_html__( "Permanent Link to %s", 'qodux_fw' ), get_the_title() ).'">' . get_the_title() . '</a></h4>';
								} else {
									$contentOutput .= '<h4 class="qodx_post_title"><span>' . get_the_title() . '</span></h4>';
								}
							}
							
							// if NOT blog slider
							if ($slider != 'true') {								
								
								if ( $read_more == 'true' ) {
									$read_more = true;
								} else {
									$read_more = false;
								}			
																	
								// if excerpt is set to Yes	
								if ($excerpt == 'true') {																	
									/* Display all post content or post excerpt */						
									if ( $full == 'true' ){
										$read_more = 'false';
										$content = get_the_content();
										$content = apply_filters('the_content', $content);
										$content = str_replace(']]>', ']]&gt;', $content);
										$contentOutput .= $content;
									} else {
										$content = QODX_VCSC_Excerpt( $excerpt_length, $read_more, $read_more_text );
										$contentOutput .= '<div class="qodx_post_excerpt">'.$content.'</div>';
									}																
								} else {
									if ( $read_more ) {
										$content = QODX_VCSC_Excerpt( $excerpt_length=0, $read_more, $read_more_text );
										$contentOutput .= '<div class="qodx_post_excerpt">'.$content.'</div>';
									}
								}																	
																	
							} // End - if NOT blog slider
							
						if ( ( $title == 'true' && $slider == 'true' ) || $excerpt == 'true' || $read_more == 'true'){	
							$contentOutput .= "\n\t" . '</div>'; // End div - "post-footer"
						}
						/* End - Content output */	
						$output .= $contentOutput;			
					/* Start - Metadata */
								if ( $meta != '' ){									
									$date = $author = $category = $tags = $views = $comments = false;									
									$metadata = array_map( 'trim', explode( ',', $meta ) );	
											
									if(is_array($metadata) && !empty($metadata)){
										
										foreach ( $metadata as $index=>$metaopt ) {												
											switch( $metaopt ) {
												case 'author'     : $author = true;   break;
												case 'categories' : $category = true; break;
												case 'tags'       : $tags = true;     break;
												case 'views'      : $views = true;    break;
												case 'comments'   : $comments = true; break;
											}											
										}	
																				
									}
									
									$output .= "\n\t\t" . '<div class="meta-block">';
										$output .= "\n\t\t" . '<div class="meta-block-container">';										
											$output .= QODX_VCSC_BlogMeta($date = false, $author, $category, $tags, $views, $comments);
										$output .= "\n\t\t" . '</div>'; // End div - "meta-block-container"			
									$output .= "\n\t\t" . '</div>';	// End div - "meta-block"							
								}
								/* End - Metadata */
							
					$output .= '</div>'; // End div - "post-block-container"										
				$output .= '</article>'; // End blog article
				
				if ($slider == 'true') {
						$output .= '</div>'; // End "swiper-slide-container"
					$output .= '</div>'; // End "swiper-slide"
				}
								
			endwhile;			
		endif;
			
		return $output;
	
	}
	
}

/*
Register WhoaThemes shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {

	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;	
	$add_qodx_extra_id            = $add_qodx_sc_func->getWTExtraId();
	$add_qodx_extra_class         = $add_qodx_sc_func->getWTExtraClass();
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name' => esc_html__( 'Blog', 'qodux_fw' ),
		'base' => 'qodx_blog',
		'icon' => 'qodx-icon-blog fa fa-newspaper-o',
		'class' => 'qodx_vc_sc_blog',
		'category' => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description' => esc_html__( 'Recent blog posts', 'qodux_fw' ),
		'params' => array(
			array(
				'type'			=> 'dropdown',
				'class'			=> '',
				'heading'		=> esc_html__( 'Columns', 'qodux_fw' ),
				'param_name'	=> 'columns',
				'admin_label'	=> true,
				'value' 		=> array(
					esc_html__( 'One', 'qodux_fw' )		=> '1',
					esc_html__( 'Two', 'qodux_fw' )		=> '2',
					esc_html__( 'Three', 'qodux_fw' )	=> '3',
					esc_html__( 'Four', 'qodux_fw' )	    => '4',
					esc_html__( 'Five', 'qodux_fw' )	    => '5',
					esc_html__( 'Six', 'qodux_fw' )	    => '6',
				),
				'std'	        => '4',
				'description'	=> esc_html__( 'How many columns?', 'qodux_fw' ),
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Max (posts number)', 'qodux_fw' ),
				'param_name'    => 'max',
				'value'         => '-1',
				'description'   => esc_html__( 'How many items do you wish to show? Set -1 to display all.', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Blog Grid Spaces', 'qodux_fw' ),
				'param_name'    => 'grid_spaces',
				'value' => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'description'   => esc_html__( 'If selected, blog articles will have spaces around.', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Show featured entry?', 'qodux_fw' ),
				'param_name'    => 'featured_entry',
				'value' => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'description'   => esc_html__( 'Display featured post entries? These could be: images, slides, videos or audios.', 'qodux_fw' )
			),					
			array(
				'type'			=> 'textfield',
				'heading'		=> esc_html__( 'Featured image width', 'qodux_fw' ),
				'param_name'	=> 'img_width',
				'value'			=> '9999',
				'description'	=> esc_html__( 'Enter the width in pixels.', 'qodux_fw' ),
			),
			array(
				'type'			=> 'textfield',
				'heading'		=> esc_html__( 'Featured image height', 'qodux_fw' ),
				'param_name'	=> 'img_height',
				'value'			=> '9999',
				"description"	=> esc_html__( 'Enter the height in pixels. Set to "9999" to disable vertical cropping and keep image proportions.', 'qodux_fw' ),
			),	
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Author avatar and name?', 'qodux_fw' ),
				'param_name'	=> 'avatar',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => 'yes' ),
				'description'   => esc_html__( 'Check this option to display the Gravatar and the author name.', 'qodux_fw' ),
			),		
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Meta information', 'qodux_fw' ),
				'param_name'    => 'meta',
				'std'           => '',
				'value'         => array(
					esc_html__( 'Date', 'qodux_fw' )       => 'date',
					esc_html__( 'Author', 'qodux_fw' )     => 'author',
					esc_html__( 'Categories', 'qodux_fw' ) => 'categories',
					esc_html__( 'Tags', 'qodux_fw' )       => 'tags',
					esc_html__( 'Views', 'qodux_fw' )      => 'views',
					esc_html__( 'Comments', 'qodux_fw' )   => 'comments'
				),
				'description'   => esc_html__( 'Display post meta information? These are: date, author, categories, tags, views, comments.', 'qodux_fw' ) . '<b>' . esc_html__( ' Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Title', 'qodux_fw' ),
				'param_name'    => 'title',
				'value' => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'description'   => esc_html__( 'Display post title?', 'qodux_fw' )
			),	
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Title linkable', 'qodux_fw' ),
				'param_name'    => 'title_linkable',
				'value'         => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'std'           => 'false',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	=> Array(
					'element'	=> 'title',
					'value'		=> 'true'
				),
				'description'   => esc_html__( 'Link on title?', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Excerpt (post content)', 'qodux_fw' ),
				'param_name'    => 'excerpt',
				'value' => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'description'   => esc_html__( 'Display post excerpt / content?', 'qodux_fw' )
			),
			array(
				'type'               => 'textfield',
				'heading'            => esc_html__( 'Excerpt (post content) length', 'qodux_fw' ),
				'param_name'         => 'excerpt_length',
				'value'              => '15',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	     => Array(
					'element'	=> 'excerpt',
					'value'		=> 'true'
				),
				'description'        => esc_html__( 'Enter a custom excerpt length. Will trim the excerpt by this number of words.', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Display full post?', 'qodux_fw' ),
				'param_name'    => 'full',
				'value' => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	     => Array(
					'element'	=> 'excerpt',
					'value'		=> 'true'
				),
				'description'   => esc_html__( 'Display all posts content instead of the auto excerpt. Excerpt option above should be \'YES\'', 'qodux_fw' )
			),	
			array(
				'type'			=> 'dropdown',
				'class'			=> '',
				'heading'		=> esc_html__( 'Read More', 'qodux_fw' ),
				'param_name'	=> 'read_more',
				'value'			=> array(
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )	=> 'false',
				),
				'description'	=> esc_html__( 'Display post readmore button after excerpt?', 'qodux_fw' ),
			),
			array(
				'type'			     => 'textfield',
				'class'			     => '',
				'heading'		     => esc_html__( 'Read More Text', 'qodux_fw' ),
				'param_name'	     => 'read_more_text',
				'value'			     => esc_html__( 'Read More', 'qodux_fw' ),
				'description'	     => esc_html__( 'Enter your custom text for the read more button.', 'qodux_fw' ),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	     => Array(
					'element'	=> 'read_more',
					'value'		=> 'true'
				),
			),		
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Display specific posts (optional)', 'qodux_fw' ),
				'param_name'    => 'posts',
				'value'         => '',
				'target'        => 'post',
				'description'   => esc_html__( 'Display only specific / selected posts.', 'qodux_fw' ) .'<b>' . esc_html__( 'Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Display from category (optional)', 'qodux_fw' ),
				'param_name'    => 'category',
				'value'         => '',
				'target'        => 'category',
				'description'   => esc_html__( 'Display posts from selected categories.', 'qodux_fw' ) .'<b>' . esc_html__( 'Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Multiple Categories (optional)', 'qodux_fw' ),
				'param_name'    => 'category__and',
				'value'         => '',
				'target'        => 'category',
				'description'   => esc_html__( 'Display posts that are in multiple categories.', 'qodux_fw' ) .'<b>' . esc_html__( 'Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Exclude Categories (optional)', 'qodux_fw' ),
				'param_name'    => 'category__not_in',
				'value'         => '',
				'target'        => 'category',
				'description'   => esc_html__( 'Exclude selected categories.', 'qodux_fw' ) .'<b>' . esc_html__( 'Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'          => 'qodx_multidropdown',
				'heading'       => esc_html__( 'Display by author (optional)', 'qodux_fw' ),
				'param_name'    => 'author',
				'value'         => '',
				'target'        => 'author',
				'description'   => esc_html__( 'Display posts by specific authors.', 'qodux_fw' ) .'<b>' . esc_html__( 'Hold the \'Ctrl\' or \'Shift\' keys while clicking to select multiple items', 'qodux_fw' ).'</b>.'
			),
			array(
				'type'			=> 'dropdown',
				'class'			=> '',
				'heading'		=> esc_html__( 'Order', 'qodux_fw' ),
				'param_name'	=> 'order',
				'description'	=> sprintf( esc_html__( 'Designates the ascending or descending order. More at %s.', 'qodux_fw' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>' ),
				'value'			=> array(
					 esc_html__( 'DESC', 'qodux_fw' )	=> 'DESC',
					 esc_html__( 'ASC', 'qodux_fw' )	=> 'ASC',
				),
			),
			array(
				'type'			=> 'dropdown',
				'class'			=> '',
				'heading'		=> esc_html__( 'Order By', 'qodux_fw' ),
				'param_name'	=> 'orderby',
				'description'	=> sprintf( esc_html__( 'Select how to sort retrieved posts. More at %s.', 'qodux_fw' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>' ),
				'value'			=> array(
					esc_html__( 'None', 'qodux_fw' )			=> 'none',
					esc_html__( 'Id', 'qodux_fw' )			    => 'ID',
					esc_html__( 'Author', 'qodux_fw' )		    => 'author',
					esc_html__( 'Title', 'qodux_fw' )		    => 'title',
					esc_html__( 'Date', 'qodux_fw' )		    => 'date',
					esc_html__( 'Modified', 'qodux_fw' )		=> 'modified',
					esc_html__( 'Random', 'qodux_fw' )			=> 'rand',
					esc_html__( 'Comment Count', 'qodux_fw' )	=> 'comment_count',
					esc_html__( 'Menu Order', 'qodux_fw' )	    => 'menu_order',
				),
				'std'	        => 'date',
			),			
			
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Pagination', 'qodux_fw' ),
				'param_name'    => 'pagination',
				'value' => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'description'   => esc_html__( 'Display pagination.', 'qodux_fw' )
			),		
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Pagination alignment', 'qodux_fw' ),
				'param_name'    => 'pagination_align',
				'value'         => array( esc_html__( 'Align left', 'qodux_fw' ) => 'left', esc_html__( 'Align right', 'qodux_fw' ) => 'right', esc_html__( 'Align center', 'qodux_fw' ) => 'center'),
				'std'           => 'center',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	     => Array(
					'element'	     => 'pagination',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Aligns pagination links to left / center / right.', 'qodux_fw' )
			),
			array(
				'type'			=> 'checkbox',
				'heading'		=> esc_html__( 'Isotope grid?', 'qodux_fw' ),
				'param_name'	=> 'isotope_grid',
				'value'			=> Array( esc_html__( 'Yes please.', 'qodux_fw' ) => 'yes' ),
				'description'   => esc_html__( 'Check this option to enable simple isotope (masonry) grid.', 'qodux_fw' ),
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Enable', 'qodux_fw' ),
				'param_name'    => 'slider',
				'value'         => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'description'   => esc_html__( 'Enables slider for displaying blog posts.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			
			// Slider Settings			
			array(
				'type'		  => 'qodx_separator',
				'heading'	  => '',
				"param_name"  => 'separator',
				'value'	      => '',
				'separator'	  => 'Slider Settings',
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description' => esc_html__( 'Below you can edit default slider settings.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),			
			array(
				'type'               => 'textfield',
				'heading'            => esc_html__( 'Autoplay', 'qodux_fw' ),
				'param_name'         => 'auto_slide',
				'value'              => '5000',
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Enables autoplay and define the time interval (in miliseconds - Ex: 3000, 4000, 5000 etc) between transitions. Set it "0" to disable autoplay.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Direction', 'qodux_fw' ),
				'param_name'         => 'direction',
				'value' 			 => array( 
					esc_html__( 'Horizontal', 'qodux_fw' ) => 'horizontal',
					esc_html__( 'Vertical', 'qodux_fw' )   => 'vertical',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Define slider direction ( horizontal / vertical ).', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Equal height for horizontal sliders?', 'qodux_fw' ),
				'param_name'         => 'equal_height',
				'value' 			 => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Set equal height for horizontal sliders. Slider will have the highest slide item size.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Effect', 'qodux_fw' ),
				'param_name'         => 'effect',
				'value' 			 => array( 
					esc_html__( 'Slide', 'qodux_fw' )     => 'slide',
					esc_html__( 'Fade', 'qodux_fw' )      => 'fade',
					esc_html__( 'Coverflow', 'qodux_fw' ) => 'coverflow',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Define slider animation effect.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'qodx_range',
				'heading'            => esc_html__( 'Items visible on Small Desktop', 'qodux_fw' ),
				'param_name'         => 'slide_items_md',
				'value'              => 2,
				'min'                => 1,
				'max'                => 4,
				'step'               => 1,
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'        => esc_html__( 'Define maximum amount of items to be visible on small desktops.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'qodx_range',
				'heading'            => esc_html__( 'Items visible on Tablet', 'qodux_fw' ),
				'param_name'         => 'slide_items_sm',
				'value'              => 2,
				'min'                => 1,
				'max'                => 4,
				'step'               => 1,
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'        => esc_html__( 'Define maximum amount of items to be visible on tablets.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'qodx_range',
				'heading'            => esc_html__( 'Items visible on Mobile', 'qodux_fw' ),
				'param_name'         => 'slide_items_xs',
				'value'              => 1,
				'min'                => 1,
				'max'                => 3,
				'step'               => 1,
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'        => esc_html__( 'Define maximum amount of items to be visible on mobiles.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Centered Slides', 'qodux_fw' ),
				'param_name'         => 'centered_slides',
				'value' 			 => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'If true, then active slide will be centered, not always on the left side.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),	
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Grab Cursor', 'qodux_fw' ),
				'param_name'         => 'grab_cursor',
				'value' 			 => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'This option may a little improve desktop usability. If true, user will see the "grab" cursor when hover on Swiper.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),	
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Simulate Touch', 'qodux_fw' ),
				'param_name'         => 'simulate_touch',
				'value' 			 => array( 
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
					esc_html__( 'No', 'qodux_fw' )    => 'false',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'If true, Swiper will accept mouse events like touch events (click and drag to change slides).', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),	
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Slider Pagination', 'qodux_fw' ),
				'param_name'         => 'slider_pag',
				'value' 			 => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Enables slider pagination.', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),	
			array(
				'type'			     => 'checkbox',
				'heading'		     => esc_html__( 'Slider Pagination Lowest?', 'qodux_fw' ),
				'param_name'	     => 'pag_lowest',
				'value'			     => Array( esc_html__( 'Yes please.', 'qodux_fw' ) => 'yes' ),
				'description'        => esc_html__( 'Check this option to display pagination in the lowest position.', 'qodux_fw' ),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency' 	     => array(
					'element' => 'slider_pag',
					'value'   => 'true'
				),
				'group'              => esc_html__( 'Slider', 'qodux_fw' )
			),			
			array(
				'type'               => 'dropdown',
				'heading'            => esc_html__( 'Slider Navigation', 'qodux_fw' ),
				'param_name'         => 'slider_nav',
				'value' 			 => array( 
					esc_html__( 'No', 'qodux_fw' )    => 'false',
					esc_html__( 'Yes', 'qodux_fw' )   => 'true',
				),
				'dependency'	     => Array(
					'element'	     => 'slider',
					'value'		     => 'true'
				),
				'description'   => esc_html__( 'Enables slider navigation ( prev / next buttons ).', 'qodux_fw' ),
				'group' => esc_html__( 'Slider', 'qodux_fw' )
			),
			
			$add_qodx_extra_id,
			$add_qodx_extra_class,
			$add_qodx_css_animation,			
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay,
			
			array(
				'type' => 'css_editor',
				'heading' => esc_html__( 'Css', 'qodux_fw' ),
				'param_name' => 'css',
				'group' => esc_html__( 'Design options', 'qodux_fw' )
			),
			
			// Load Custom CSS/JS File
			array(
				'type'               => 'qodx_loadfile',
				'heading'            => '',
				'param_name'         => 'el_file',
				'value'              => '',
				'file_path'          => 'qodx-visual-composer-extend-element.min.js',
				'param_holder_class' => 'qodx_loadfile_field',
				'description'        => ''
			)
		)
	));
	
}