<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_Custom_heading extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
				
	protected function content($atts, $content = null) {
		
		extract( shortcode_atts( array(
			'tag'             => 'h2',
			'style'           => 'qodx_cheading_3',
			'align'           => 'left',
			'color'           => '',
			'background'      => '',
									
			'el_id'           => '',
			'el_class'        => '',
    		'css_animation'   => '',
    		'anim_type'       => '',
    		'anim_delay'      => '',			
			'css'             => ''		
		), $atts ) );
								
		$color          = esc_attr($color);
		$background     = esc_attr($background);
				
		$sc_class = 'qodx_cheading_sc';	
					
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = esc_attr( trim($el_id) );
		} else {
			$el_id = $sc_class . '-' . $id;
		}								
					
		$el_class = esc_attr( $this->getExtraClass($el_class) );
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);	
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);
		
		$el_style = '';
		
		if ( $color != '' ) {
			$color = 'color: ' . $color . ';';
		}
		if ( $background != '' ) {
			$background = 'background: ' . $background . ';';
		}
	
		if ( $background != '' || $color != '' ) {
			$el_style = ' style="'. $color . $background .'"';
		}
		
		$alignment = !empty($align) ? 'qodx_align_'.$align : '';
		
		$content = wpb_js_remove_wpautop($content); // fix unclosed/unwanted paragraph tags in $content
		
		$output = '<div id="'.$el_id.'" class="'.$css_class.' '.$style.' '.$alignment.'"'.$anim_data.'>';
		
		switch($style) {
			case "qodx_cheading_1":
			case "qodx_cheading_4":
				$output .= '<'.$tag.$el_style.'>'.$content.'</'.$tag.'>';
				break;
			case "qodx_cheading_2":
				if ($align == 'left' || $align == 'center') { // center is not working with this anyway
					$output .= '<'.$tag.$el_style.'>'.$content.'</'.$tag.'>';
					$output .= '<div class="qodx_cheading_sep_wrap"><div class="qodx_cheading_sep"></div></div>';
				} else { // right
					$output .= '<div class="qodx_cheading_sep_wrap"><div class="qodx_cheading_sep"></div></div>';
					$output .= '<'.$tag.$el_style.'>'.$content.'</'.$tag.'>';
				}
				break;
			case "qodx_cheading_3":
			default:
				$output .= '<'.$tag.$el_style.'><span>'.$content.'</span></'.$tag.'>';
				break;
		}
		$output .= '</div>';
		
        return $output;
								
    }
	
}
	
/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {

	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;
	$add_qodx_extra_id            = $add_qodx_sc_func->getWTExtraId();
	$add_qodx_extra_class         = $add_qodx_sc_func->getWTExtraClass();
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name'          => esc_html__( 'Custom Heading', 'qodux_fw' ),
		'base'          => 'qodx_custom_heading',
		'icon'          => 'qodx-icon-custom_heading fa fa-font',
		'class'         => 'qodx_vc_sc_custom_heading',
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Add custom heading text', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'        => 'textarea',
				'heading'     => esc_html__( 'Text', 'qodux_fw' ),
				'param_name'  => 'content',
				'admin_label' => true,
				'value'       => esc_html__( 'This is a custom heading element', 'qodux_fw' ),
				'description' => esc_html__( 'Enter your custom heading content.', 'qodux_fw' ),
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Element tag', 'qodux_fw' ),
				'param_name'  => 'tag',
				'value'       => array(
					esc_html__( 'H1', 'qodux_fw' )   => 'h1', 
					esc_html__( 'H2', 'qodux_fw' )   => 'h2',
					esc_html__( 'H3', 'qodux_fw' )   => 'h3',
					esc_html__( 'H4', 'qodux_fw' )   => 'h4',
					esc_html__( 'H5', 'qodux_fw' )   => 'h5',
					esc_html__( 'H6', 'qodux_fw' )   => 'h6'
				),
				'std'	      => 'h2',
				'description' => esc_html__( 'Select the element tag.', 'qodux_fw' )
			),
			array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'Heading style', 'qodux_fw' ),
				'param_name'  => 'style',
				'value'       => array(
					esc_html__( 'Style #1', 'qodux_fw' )   => 'qodx_cheading_1',
					esc_html__( 'Style #2', 'qodux_fw' )   => 'qodx_cheading_2', 
					esc_html__( 'Style #3', 'qodux_fw' )   => 'qodx_cheading_3', 
					esc_html__( 'Style #4', 'qodux_fw' )   => 'qodx_cheading_4'
				),
				'std'	      => 'qodx_cheading_3',
				'description' => esc_html__( 'Select the element tag.', 'qodux_fw' )
			),
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Text align', 'qodux_fw' ),
				'param_name'    => 'align',
				'value'         => array( esc_html__( 'Align left', 'qodux_fw' ) => 'left', esc_html__( 'Align right', 'qodux_fw' ) => 'right', esc_html__( 'Align center', 'qodux_fw' ) => 'center'),
				'std'           => 'left',
				'description'   => esc_html__( 'Select text alignment.', 'qodux_fw' ).' <strong>' .esc_html__( 'Style #2 is not working on center.', 'qodux_fw' ) .'</strong>'
			),
			array(
				'type'          => 'colorpicker',
				'heading'       => esc_html__( 'Text color', 'qodux_fw' ),
				'param_name'    => 'color',
				'description'   => esc_html__( 'Select text color.', 'qodux_fw' )
			),
			array(
				'type'          => 'colorpicker',
				'heading'       => esc_html__( 'Custom heading background', 'qodux_fw' ),
				'param_name'    => 'background',
				'description'   => esc_html__( 'Select custom heading background.', 'qodux_fw' )
			),	
			
			$add_qodx_extra_id,
			$add_qodx_extra_class,
			$add_qodx_css_animation,
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay,
			
			array(
				'type'          => 'css_editor',
				'heading'       => esc_html__( 'Css', 'qodux_fw' ),
				'param_name'    => 'css',
				'group'         => esc_html__( 'Design options', 'qodux_fw' )
			)
		)
	));	
	
}