<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_spacer extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
			
	protected function content($atts, $content = null) {
		
		extract( shortcode_atts( array(
			'height'        => '',
			'el_id'         => '',
			'el_class'      => '',
			'el_style'      => '',
			
    		'css_animation' => '',
    		'anim_type'     => '',
    		'anim_delay'    => '',		
			'css'           => ''		
		), $atts ) );
		
		$sc_class = 'qodx_spacer_sc';
				
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = esc_attr( trim($el_id) );
		} else {
			$el_id = $sc_class . '-' . $id;
		}
		
		$height   = (int)$height;		
		
		$sc_class .= ' qodx_clearboth';
		$sc_el_style = 'height:'.$height.'px; line-height:'.$height.'px;';
		
		$el_style = esc_attr($sc_el_style.$el_style);
					
		$el_class = esc_attr( $this->getExtraClass($el_class) );		
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);		
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);
		
		$el_style = $this->qodx_sc->getWTElementStyle($el_style) ;
				
		$output = '<div id="'.$el_id.'" class="'.$css_class.'"'.$el_style.'></div>';
		
        return $output;
    }
	
}

/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {
	
	vc_map( array(
		'name'          => esc_html__( 'Spacer / Clear', 'qodux_fw' ),
		'base'          => 'qodx_spacer',
		'icon'          => 'qodx-icon-spacer fa fa-sort',
		'class'         => 'qodx_vc_sc_spacer',
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Place space / clear element', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'        => 'qodx_range',
				'heading'     => esc_html__( 'Spacer height', 'qodux_fw' ),
                "admin_label" => true,
				'param_name'  => 'height',
				'value'       => 10,
				'min'         => 0,
				'max'         => 500,
				'step'        => 1,
				'unit'        => 'px',
				'description' => esc_html__( 'Define spacer height in px.', 'qodux_fw' )
			),
			// Extra Settings
			array(
				'type'		  => 'qodx_separator',
				'heading'	  => '',
				"param_name"  => 'separator',
				'value'	      => '',
				'separator'	  => 'Extra Settings',
				'dependency'  => array( 'element' => 'type', 'value' => 'carousel' ),
				'description' => esc_html__( 'Below you can add extra settings.', 'qodux_fw' )
			),
			array(
				'type'               => 'textfield',
				'heading'            => esc_html__( 'Extra Unique ID name', 'qodux_fw' ),
				'param_name'         => 'el_id',
				'param_holder_class' => 'border_box qodx_dependency',
				'description'        => esc_html__( 'If you wish to style particular content element differently, then use this field to add a UNIQUE ID name and then refer to it in your css file.', 'qodux_fw' )
			),
			array(
				'type'               => 'textfield',
				'heading'            => esc_html__( 'Extra class name', 'qodux_fw' ),
				'param_name'         => 'el_class',
				'param_holder_class' => 'border_box qodx_dependency',
				'description'        => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'qodux_fw' )
			),
			array(
				'type'               => 'textarea',
				'heading'            => esc_html__( 'Extra style', 'qodux_fw' ),
				'param_name'         => 'el_style',
				'param_holder_class' => 'border_box qodx_dependency',
				'description'        => esc_html__( 'If you wish to use inline styles, then use this field. The style attribute can contain any CSS property.', 'qodux_fw' ).' <br>'. esc_html__( 'Example: color:sienna;margin-left:20px;', 'qodux_fw' )
			),
			
			// Load Custom CSS/JS File
			array(
				'type'               => 'qodx_loadfile',
				'heading'            => '',
				'param_name'         => 'el_file',
				'value'              => '',
				'file_path'          => 'qodx-visual-composer-extend-element.min.js',
				'param_holder_class' => 'qodx_loadfile_field',
				'description'        => ''
			),
		)
	));
	
}