<?php

// File Security Check
if (!defined('ABSPATH')) die('-1');

/*
Register Qodux shortcode.
*/

class WPBakeryShortCode_QODX_tag extends WPBakeryShortCode {
	
	private $qodx_sc;
	
	public function __construct($settings) {
        parent::__construct($settings);
		$this->qodx_sc = new QODX_VCSC_SHORTCODE;
	}
			
	protected function content($atts, $content = null) {
		
		extract( shortcode_atts( array(
			'type'          => 'div',
			'el_id'         => '',
			'el_class'      => '',
			'el_style'      => '',
    		'css_animation' => '',
    		'anim_type'     => '',
    		'anim_delay'    => '',			
			'css'           => ''		
		), $atts ) );
		
		$sc_class = 'qodx_tag_sc';
				
		$id = mt_rand(9999, 99999);
		if (trim($el_id) != false) {
			$el_id = esc_attr( trim($el_id) );
		} else {
			$el_id = $sc_class . '-' . $id;
		}		
		
		$el_style = esc_attr($el_style);
				
		$el_class = esc_attr( $this->getExtraClass($el_class) );		
		$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $sc_class.$el_class.vc_shortcode_custom_css_class($css, ' '), $this->settings['base']);		
		$css_class .= $this->qodx_sc->getWTCSSAnimationClass($css_animation,$anim_type);
		$anim_data = $this->qodx_sc->getWTCSSAnimationData($css_animation,$anim_delay);
		
		$el_style = $this->qodx_sc->getWTElementStyle($el_style);
		
		$content = wpb_js_remove_wpautop($content); // fix unclosed/unwanted paragraph tags in $content
		
		$output = '<'.$type.' id="'.$el_id.'" class="'.$css_class.'"'.$el_style.$anim_data.'>';
	        $output .= "\n\t\t\t".$content;
        $output .= '</'.$type.'>';
		
        return $output;
    }
	
}

/*
Register Qodux shortcode within Visual Composer interface.
*/

if (function_exists('vc_map')) {

	$add_qodx_sc_func             = new QODX_VCSC_SHORTCODE;
	$add_qodx_css_animation       = $add_qodx_sc_func->getWTAnimations();
	$add_qodx_css_animation_type  = $add_qodx_sc_func->getWTAnimationsType();
	$add_qodx_css_animation_delay = $add_qodx_sc_func->getWTAnimationsDelay();
	
	vc_map( array(
		'name'          => esc_html__( 'Tag', 'qodux_fw' ),
		'base'          => 'qodx_tag',
		'icon'          => 'qodx-icon-tag fa fa-code',
		'class'         => 'qodx_vc_sc_tag',
		'category'      => esc_html__( 'by Qodux', 'qodux_fw' ),
		'description'   => esc_html__( 'Place HTML tags ( div, section, span, i )', 'qodux_fw' ),
		'params'        => array(
			array(
				'type'          => 'dropdown',
				'heading'       => esc_html__( 'Type', 'qodux_fw' ),
				'param_name'    => 'type',
				'value'         => array(esc_html__( 'Div', 'qodux_fw' ) => 'div', esc_html__( 'Section', 'qodux_fw' ) => 'section', esc_html__( 'Span', 'qodux_fw' ) => 'span', esc_html__( 'I', 'qodux_fw' ) => 'i' ),
				'description'   => esc_html__( 'Select the html tag you need. This shortcode is very useful because you can create block elements withought html coding. You can give them an id, a class attribute or set an inline style.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Extra Unique ID name', 'qodux_fw' ),
				'param_name'    => 'el_id',
				'description'   => esc_html__( 'If you wish to style particular content element differently, then use this field to add a UNIQUE ID name and then refer to it in your css file.', 'qodux_fw' )
			),
			array(
				'type'          => 'textfield',
				'heading'       => esc_html__( 'Extra class name', 'qodux_fw' ),
				'param_name'    => 'el_class',
				'description'   => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'qodux_fw' )
			),
			array(
				'type'          => 'textarea',
				'heading'       => esc_html__( 'Extra style', 'qodux_fw' ),
				'param_name'    => 'el_style',
				'description'   => esc_html__( 'If you wish to use inline styles, then use this field. The style attribute can contain any CSS property.', 'qodux_fw' ).' <br>'. esc_html__( 'Example: color:sienna;margin-left:20px;', 'qodux_fw' )
			),
			array(
				'type'          => 'textarea_html',
				'holder'        => 'div',
				'class'         => '',
				'heading'       => esc_html__( 'Content', 'qodux_fw' ),
				'param_name'    => 'content',
				'value'         => esc_html__( 'I am test text block. Click edit button to change this text.', 'qodux_fw' ),
				'description'   => esc_html__( 'Enter your content.', 'qodux_fw' )
			),
			
			$add_qodx_css_animation,
			$add_qodx_css_animation_type,
			$add_qodx_css_animation_delay,
			
			array(
				'type'          => 'css_editor',
				'heading'       => esc_html__( 'Css', 'qodux_fw' ),
				'param_name'    => 'css',
				'group'         => esc_html__( 'Design options', 'qodux_fw' )
			)
		)
	));
	
}