<?php
/**
 * Contact Info Widget Class
 */
class Focus_WP_Widget_Contact_Info extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_contact_info', 'description' => esc_html__( 'A list of contact informations', 'focus_wp' ) );
		parent::__construct('contact_info', esc_html__( 'Qodux - Contact Info', 'focus_wp' ), $widget_ops);
		
	}
	
	function widget( $args, $instance ) {		
		extract( $args );
		$title = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
		
		$name = $instance['name'];
		$phone = $instance['phone'];
		$email = $instance['email'];
		$link = $instance['link'];
		$twitter = $instance['twitter'];
		$address = $instance['address'];
		$city = $instance['city'];
		$state = $instance['state'];
		$zip = $instance['zip'];
		$text = $instance['text'];		
						
		echo balanceTags( $before_widget );
		if ( $title)
			echo balanceTags( $before_title . $title . $after_title );
		
		?>
        <div class="wt_contactInfo">
			<div class="wt_contactInfoWrap">   	
			<?php if(!empty($name)): ?><div class="wt_contactName info-block"><div class="info-block-container"><i class="fa fa-user circle-icon-block circle-icon-block-sm"></i><p><?php echo esc_attr( $name );?></p></div></div><?php endif; ?>
            <?php if(!empty($phone)): ?><div class="wt_contactPhone info-block"><div class="info-block-container"><a href="<?php echo esc_attr( $phone );?>" title="<?php echo esc_attr( $phone );?>" class="main-link"><i class="fa fa-phone circle-icon-block circle-icon-block-sm"></i><p><?php echo esc_attr( $phone );?></p></a></div></div><?php endif; ?><?php if(!empty($email)): ?><div class="wt_contactMail info-block"><div class="info-block-container"><a href="mailto:<?php echo esc_attr( $email );?>" title="<?php echo esc_attr( $email );?>" class="main-link nospam" rel="nofollow"><i class="fa fa-envelope circle-icon-block circle-icon-block-sm"></i><p><?php echo esc_attr( $email );?></p></a></div></div><?php endif; ?>
            <?php if(!empty($link)): ?><div class="wt_contactLink info-block"><div class="info-block-container"><i class="fa fa-link circle-icon-block circle-icon-block-sm"></i><a href="<?php echo esc_attr( $link );?>" target="_blank"><p><?php echo esc_attr( $link );?></p></a></div></div><?php endif; ?>
            <?php if(!empty($twitter)): ?><div class="wt_contactTwitter info-block"><div class="info-block-container"><i class="fa fa-twitter circle-icon-block circle-icon-block-sm"></i><a href="<?php echo esc_attr( $twitter );?>" target="_blank"><p><?php echo esc_attr( $twitter );?></p></a></div></div><?php endif; ?>
            <?php if ( !empty($address) || !empty($city) || !empty($zip) || !empty($state) ): ?>
            	<div class="wt_contactAddress info-block"><div class="info-block-container"><i class="fa fa-map-marker circle-icon-block circle-icon-block-sm"></i><p>
					<?php if(!empty($address)): ?><?php echo esc_attr( $address );?>, <?php endif; ?>
                    <?php if(!empty($city)): ?><?php echo esc_attr( $city );?>, <?php endif; ?>
                    <?php if(!empty($zip)): ?><?php echo esc_attr( $zip );?>, <?php endif; ?>
                    <?php if(!empty($state)): ?><?php echo esc_attr( $state );?><?php endif; ?>
                </p></div></div>
            <?php endif; ?>            
			<?php if(!empty($text)): ?><div class="wt_contactText info-block"><div class="info-block-container"><p><?php echo esc_attr( $text );?></p></div></div><?php endif; ?>
					
			</div>
        </div>
		<?php
		echo  balanceTags( $after_widget );

	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['name'] = strip_tags($new_instance['name']);
		$instance['phone'] = strip_tags($new_instance['phone']);
		$instance['email'] = strip_tags($new_instance['email']);
		$instance['link'] = strip_tags($new_instance['link']);
		$instance['twitter'] = strip_tags($new_instance['twitter']);
		$instance['address'] = strip_tags($new_instance['address']);
		$instance['city'] = strip_tags($new_instance['city']);
		$instance['state'] = strip_tags($new_instance['state']);
		$instance['zip'] = strip_tags($new_instance['zip']);
		$instance['text'] = strip_tags($new_instance['text']);
		

		return $instance;
	}

	function form( $instance ) {
		//Defaults		
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$name = isset($instance['name']) ? esc_attr($instance['name']) : '';
		$phone = isset($instance['phone']) ? esc_attr($instance['phone']) : '';
		$email = isset($instance['email']) ? esc_attr($instance['email']) : '';
		$link = isset($instance['link']) ? esc_attr($instance['link']) : '';
		$twitter = isset($instance['twitter']) ? esc_attr($instance['twitter']) : '';
		$address = isset($instance['address']) ? esc_attr($instance['address']) : '';
		$city = isset($instance['city']) ? esc_attr($instance['city']) : '';
		$state = isset($instance['state']) ? esc_attr($instance['state']) : '';
		$zip = isset($instance['zip']) ? esc_attr($instance['zip']) : '';
		$text = isset($instance['text']) ? esc_attr($instance['text']) : '';
	?>

		<p><label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e( 'Title:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>
		
		<p><label for="<?php echo esc_attr( $this->get_field_id('name') ); ?>"><?php esc_html_e( 'Name:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('name') ); ?>" name="<?php echo esc_attr( $this->get_field_name('name') ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>" /></p>
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('phone') ); ?>"><?php esc_html_e( 'Phone:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('phone') ); ?>" name="<?php echo esc_attr( $this->get_field_name('phone') ); ?>" type="text" value="<?php echo esc_attr( $phone ); ?>" /></p>
        		
        <p><label for="<?php echo esc_attr( $this->get_field_id('email') ); ?>"><?php esc_html_e( 'Email:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('email') ); ?>" name="<?php echo esc_attr( $this->get_field_name('email') ); ?>" type="text" value="<?php echo esc_attr( $email ); ?>" /></p>     
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('link') ); ?>"><?php esc_html_e( 'Link:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('link') ); ?>" name="<?php echo esc_attr( $this->get_field_name('link') ); ?>" type="text" value="<?php echo esc_attr( $link ); ?>" /></p>   
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('twitter') ); ?>"><?php esc_html_e( 'Twitter:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('twitter') ); ?>" name="<?php echo esc_attr( $this->get_field_name('twitter') ); ?>" type="text" value="<?php echo esc_attr( $twitter ); ?>" /></p>   
				
		<p><label for="<?php echo esc_attr( $this->get_field_id('address') ); ?>"><?php esc_html_e( 'Address:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('address') ); ?>" name="<?php echo esc_attr( $this->get_field_name('address') ); ?>" type="text" value="<?php echo esc_attr( $address ); ?>" /></p>
		
		<p><label for="<?php echo esc_attr( $this->get_field_id('city') ); ?>"><?php esc_html_e( 'City:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('city') ); ?>" name="<?php echo esc_attr( $this->get_field_name('city') ); ?>" type="text" value="<?php echo esc_attr( $city ); ?>" /></p>
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('zip') ); ?>"><?php esc_html_e( 'Zip:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('zip') ); ?>" name="<?php echo esc_attr( $this->get_field_name('zip') ); ?>" type="text" value="<?php echo esc_attr( $zip ); ?>" /></p>
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('state') ); ?>"><?php esc_html_e( 'State:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('state') ); ?>" name="<?php echo esc_attr( $this->get_field_name('state') ); ?>" type="text" value="<?php echo esc_attr( $state ); ?>" /></p>	
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('text') ); ?>"><?php esc_html_e( 'Introduce text:', 'focus_wp' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('text') ); ?>" type="text" value="<?php echo esc_attr( $text ); ?>" /></p>	
		
<?php
	}

}
